# coding=utf-8

from __future__ import unicode_literals
from collections import OrderedDict

from .. import Provider as AddressProvider


class Provider(AddressProvider):
    street_suffixes = OrderedDict(
        (('utca', 0.75), ('út', 0.1), ('tér', 0.1), ('köz', 0.001), ('körút', 0.001), ('sétány', 0.001)))

    street_name_formats = (
        '{{frequent_street_name}} {{street_suffix}}',
        '{{real_city_name}}i {{street_suffix}}',
        '{{city_part}}{{city_suffix}}i {{street_suffix}}',
        '{{city_prefix}}{{city_part}}i {{street_suffix}}')

    #   Currently deprecated.
    #   secondary_address_formats = ("#.em #.", "##. em. #.")

    city_formats = ('{{city_prefix}}{{city_part}}{{city_suffix}}',
                    '{{city_part}}{{city_suffix}}', '{{real_city_name}}')

    street_address_formats = ('{{street_name}} {{building_number}}',)

    address_formats = ("{{street_address}}\n{{postcode}} {{city}}",)

    frequent_street_names = (
        'Ady Endre',
        'Dózsa György',
        'Petőfi',
        'Petőfi Sándor',
        'Arany János',
        'Béke',
        'Szabadság',
        'Kossuth',
        'József Attila')

    # The 'real city name' generator includes a number of real cities of
    # Hungary that no generator could feasibly dispense. Please note that the
    # post code generator is, at this point, not capable of generating a
    # fitting post code. In Hungary, post codes are determined by the county of
    # the place (see the county generator), and for this reason, often there
    # will be a discrepancy. A patch is in the works - until then, use
    # Wikipedia to resolve postcode issues.
    #
    # This generator was created by collecting the 30 largest Hungarian places
    # by population, based on the Hungarian Gazetteer generated with effect as
    # of 01 January 2016 (http://www.ksh.hu/docs/hun/hnk/hnk_2016.pdf).

    real_city_names = (
        'Budapest',
        'Debrecen',
        'Szeged',
        'Miskolc',
        'Pécs',
        'Győr',
        'Nyíregyháza',
        'Kecskemét',
        'Székesfehérvár',
        'Szombathely',
        'Szolnok',
        'Tatabánya',
        'Érd',
        'Kaposvár',
        'Sopron',
        'Veszprém',
        'Békéscsaba',
        'Zalaegerszeg',
        'Eger',
        'Nagykanizsa',
        'Dunaújváros',
        'Hódmezővásárhely',
        'Dunakeszi',
        'Szigetszentmiklós',
        'Cegléd',
        'Baja',
        'Salgótarján',
        'Ózd',
        'Vác',
        'Mosonmagyaróvár')

    city_prefs = (
        'kis',
        'nagy',
        'szent',
        'duna',
        'tisza',
        'alsó',
        'felső',
        'belső',
        'bakony',
        'vác',
        'mező',
        'nyék',
        'nyír',
        'balaton',
        'borsod',
        'buda',
        'hajdú',
        'kun',
        'moson',
        'pilis',
        'új',
        'egyházas',
        'dráva',
        'magyar',
        'mátra',
        'somogy',
        'lajos',
        'bács',
        'békés',
        'puszta',
        'orosz',
        'rác',
        'szerb',
        'német',
        'török')

    city_parts = (
        'híd',
        'györgy',
        'mindszent',
        'kereszt',
        'márton',
        'hát',
        'hetven',
        'mellék',
        'tamási',
        'tapolca',
        'fürdő',
        'liget',
        'szék',
        'tót',
        '')

    city_suffixes = (
        'háza',
        'németi',
        'devecser',
        'fa',
        'nádasd',
        'apáti',
        'falu',
        'falva',
        'vég',
        'vár',
        'vára',
        'várad',
        'hida',
        'kövesd',
        'bánya',
        'halas',
        'berény',
        'kőrös',
        'haraszti',
        'város')

    counties = (
        'Bács-Kiskun',
        'Baranya',
        'Békés',
        'Borsod-Abaúj-Zemplén',
        'Csongrád',
        'Fejér',
        'Győr-Moson-Sopron',
        'Hajdú-Bihar',
        'Heves',
        'Jász-Nagykun-Szolnok',
        'Komárom-Esztergom',
        'Nógrád',
        'Pest',
        'Somogy',
        'Szabolcs-Szatmár-Bereg',
        'Tolna',
        'Vas',
        'Veszprém',
        'Zala')

    countries = (
        "Afganisztán", "Aland-szigetek", "Albánia", "Algéria", "Amerikai Szamoa", "Amerikai Virgin-szigetek", "Andorra",
        "Angola", "Anguilla", "Antarktisz", "Antigua és Barbuda", "Apostoli Szentszék", "Argentína", "Aruba",
        "Ausztrália", "Ausztria", "Amerikai Egyesült Államok Külső Szigetei", "Azerbajdzsán", "Bahama-szigetek",
        "Bahrein", "Banglades", "Barbados", "Fehéroroszország", "Belgium", "Belize", "Benin", "Bermuda", "Bhután",
        "Bissa -Guinea", "Bolívia", "Bosznia-Hercegovina", "Botswana", "Bouvet-sziget", "Brazília",
        "Brit Indiai-óceáni Terület", "Brit Virgin - szigetek", "Brunei", "Bulgária", "Burkina Faso", "Burundi",
        "Chile", "Ciprus", "Comore-szigetek", "Cook-szigetek", "Costa Rica", "Csád", "Csehország", "Dánia",
        "Dél-Afrika", "Dél-Korea", "Dominika", "Dominikai Köztársaság", "Dzsibuti", "Ecuador", "Egyenlítői-Guinea",
        "Egyesült Államok", "Egyesült Arab Emírségek", "Egyesült Királyság", "Egyiptom", "Elefántcsontpart", "Eritrea",
        "Északi Mariana-szigetek", "Észak-Korea", "Észtország", "Etiópia", "Falkland-szigetek", "Feröer szigetek",
        "Fidzsi-szigetek", "Finnország", "Francia Déli Területek", "Francia Guyana", "Francia Polinézia",
        "Franciaország", "Fülöp-szigetek", "Gabon", "Gambia", "Ghána", "Gibraltár", "Görögország", "Grenada",
        "Grönland", "Grúzia", "Guadeloupe", "Guam", "Guatemala", "Guinea", "Guyana", "Haiti", "Holland Antillák",
        "Hollandia", "Honduras", "Hongkong", "Horvátország", "India", "Indonézia", "Irak", "Irán", "Írország", "Izland",
        "Izrael", "Jamaica", "Japán", "Jemen", "Jordánia", "Kajmán-szigetek", "Kambodzsa", "Kamerun", "Kanada",
        "Karácsony-sziget", "Katar", "Kazahsztán", "Kelet-Timor", "Kenya", "Kína", "Kirgizisztán", "Kiribati",
        "Keeling-szigetek", "Kolumbia", "Kongó", "Kongói Demokratikus Köztársaság", "Közép-afrikai Köztársaság", "Kuba",
        "Kuvait", "Laosz", "Lengyelország", "Lesotho", "Lettország", "Libanon", "Libéria", "Líbia", "Liechtenstein",
        "Litvánia", "Luxemburg", "Macedónia", "Madagaszkár", "Magyarország", "Makaó", "Malajzia", "Malawi",
        "Maldív-szigetek", "Mali", "Málta", "Marokkó", "Marshall-szigetek", "Martinique", "Mauritánia", "Mauritius",
        "Mayotte", "Mexikó", "Mianmar", "Mikronézia", "Moldova", "Monaco", "Mongólia", "Montenegró", "Montserrat",
        "Mozambik", "Namíbia", "Nauru", "Németország", "Nepál", "Nicaragua", "Niger", "Nigéria", "Niue",
        "Norfolk-sziget", "Norvégia", "Nyugat-Szahara", "Olaszország", "Omán", "Oroszország", "Örményország",
        "Pakisztán", "Palau", "Panama", "Pápua", "Új-Guinea", "Paraguay", "Peru", "Pitcairn-szigetek", "Portugália",
        "Puerto Rico", "Réunion", "Románia", "Ruanda", "Saint Kitts és Nevis", "Saint Lucia",
        "Saint-Pierre és Miquelon", "Saint Vincent és Grenadine-szigetek", "Salamon-szigetek", "Salvador", "San Marino",
        "São Tomé és Príncipe", "Seychelle-szigetek", "Sierra Leone", "Spanyolország", "Srí Lanka", "Suriname", "Svájc",
        "Svalbard szigetek", "Svédország", "Szamoa", "Szaúdi-Arábia", "Szenegál", "Szent Ilona", "Szerbia", "Szingapúr",
        "Szíria", "Szlovákia", "Szlovénia", "Szomália", "Szudán", "Szváziföld", "Tádzsikisztán", "Tajvan", "Tanzánia",
        "Thaiföld", "Togo", "Tokelau-szigetek", "Tonga", "Törökország", "Trinidad és Tobago", "Tunézia",
        "Turks- és Caicos-szigetek", "Tuvalu", "Türkmenisztán", "Uganda", "Új-Kaledónia", "Új-Zéland", "Ukrajna",
        "Uruguay", "Üzbegisztán", "Vanuatu", "Venezuela", "Vietnam", "Wallis és Futuna", "Zambia", "Zimbabwe",
        "Zöld-foki szigetek")

    def county(self):
        return self.random_element(self.counties)

    def street_address_with_county(self):
        return "{street_address}\n{county} megye\n{postcode} {city}".format(
            street_address=self.street_address(),
            county=self.county(),
            postcode=self.postcode(),
            city=self.city().capitalize())

    def city_prefix(self):
        return self.random_element(self.city_prefs)

    def city_part(self):
        return self.random_element(self.city_parts)

    def real_city_name(self):
        return self.random_element(self.real_city_names)

    def frequent_street_name(self):
        return self.random_element(self.frequent_street_names)

    def postcode(self):
        return "H-{}{}{}{}".format(
            super(
                Provider, self).random_digit_not_null(), super(
                Provider, self).random_digit(), super(
                Provider, self).random_digit(), super(
                    Provider, self).random_digit())

    def street_name(self):
        return super(Provider, self).street_name().capitalize()

    def building_number(self):
        numeric_part = super(Provider, self).random_int(1, 250)
        return str(numeric_part) + "."



# -*- coding: utf-8 -*-

from __future__ import unicode_literals
from .. import Provider as CompanyProvider


class Provider(CompanyProvider):

    company_names = [
        'گروه سیمان',
        'گروه فلزات اساسي',
        'ایران گچ',
        'آلومتك',
        'ساروج بوشهر',
        'آلومينيوم ايران',
        'سيمان  ساوه',
        'ایران ذوب',
        'سيمان اردبيل و آهك آذرشهر',
        'پارس مولیبدن',
        'سيمان اروميه',
        'ذوب روی اصفهان',
        'سيمان اصفهان',
        'صنايع مس شهيد باهنر',
        'سيمان ايلام',
        'صنایع خالص سازان روی زنجان',
        'سيمان بجنورد',
        'صنعتی و سرمایه گذاری سپنتا',
        'سيمان بهبهان',
        'كالسيمين',
        'سيمان تهران',
        'گروه كارخانه هاي توليدي نورد آلومينيوم',
        'سيمان خاش',
        'ملي سرب و روي ايران',
        'سيمان خزر',
        'ملی صنایع مس ایران',
        'سيمان داراب',
        'آلومراد',
        'سيمان دورود',
        'آلومينيوم المهدي',
        'سيمان سفيدني ريز',
        'آلومينيوم پارس',
        'سيمان شاهرود',
        'کارخانجات تولیدی مواد الومینیوم',
        'سيمان شرق',
        'مجتمع ذوب و احیای روی قشم',
        'سيمان شمال',
        'مجتمع صنايع الومينيوم جنوب',
        'سيمان صوفيان',
        'مس تکنار',
        'سيمان غرب',
        'گروه کانی های فلزی',
        'سيمان فارس',
        'آلوميناي ايران',
        'سيمان قاين',
        'تهيه و توليد مواد اوليه فولاد خراسان',
        'سيمان كارون',
        'سنگ آهن مركزي ايران',
        'سيمان كرمان',
        'هرمز انرژی',
        'سيمان مازندران',
        'واحد طلای موته',
        'سيمان هرمزگان',
        'واحد پیربکران',
        'سيمان هگمتان',
        'واحد فسفات اسفردی',
        'سیمان خوزستان',
        'واحد نخلک',
        'سیمان دشتستان',
        'ويتانا',
        'سیمان زابل',
        'گروه صنایع غذایی',
        'سیمان فارس نو',
        'کشاورزی و تحقیقاتی نوین زعفران',
        'سیمان لار سبزوار',
        'گلستان',
        'سیمان لارستان',
        'آرد زر',
        'سیمان لامرد',
        'اروم آدا',
        'سیمان مجد خواف',
        'ایران گلاب مرغوب',
        'سیمان ممتازان کرمان',
        'بيسكوئيت گرجي',
        'فراورده سیمان شرق',
        'تحول چاشنی توس',
        'گچ ماشيني فارس',
        'تهیه و بسته بندی خشکبار آرات',
        'سیمان آذر آبادگان خوی',
        'توسعه کشت ذرت',
        'سیمان بوهروک یزد',
        'تولیدی آرد البرز',
        'سیمان جوین',
        'تولیدی زعفران سحرخیز',
        'سیمان قشم',
        'خوراك دام پارس',
        'سیمان کردستان',
        'دشت مرغاب',
        'گچ تهران',
        'روغن نباتي پارس',
        'گروه فولاد',
        'روغن نباتي جهان',
        'پلی ران اتصال',
        'روغن نباتی گلناز',
        'توليدی لوله هاي پلي اتيلن دوجداره بوشهر',
        'روغنکشی خرمشهر',
        'تولید لوله و پوشش سلفچگان',
        'زر ماکارون',
        'سلفچگان',
        'سالمين',
        'ذوب آهن اصفهان',
        'سپتیکو',
        'ساخته های فلزی اصفهان',
        'سحر همدان',
        'صنايع فرو آلياژ ايران',
        'سقزسازی کردستان',
        'صنايع گالوانيزه فجر سپاهان',
        'شاد گل نیشابور',
        'صنایع فولاد آلياژي يزد',
        'شهد ايران',
        'فولاد اکسین خوزستان',
        'صنایع غذایی مینو شرق',
        'فولاد آلیاژی ایران',
        'صنعتي  پارس مينو',
        'فولاد خوزستان',
        'صنعتي مينو خرم دره',
        'فولاد صنعت مهدی',
        'فراورده های سیب زمینی پریس اصفهان',
        'فولاد مباركه اصفهان',
        'فرآورده های گوشتی تهران',
        'کارخانجات نورد لوله یاران',
        'كشت و صنعت پياذر',
        'کاوه کشاورز',
        'كيوان',
        'گروه صنعتي سپاهان',
        'کشت و صنعت اشراق',
        'لوله و پروفیل سپنتا تهران',
        'کشت و صنعت قطران گل ایران',
        'لوله و ماشين سازي ايران',
        'کشت وصنعت روژین تاک',
        'مجتمع فولاد خراسان',
        'کشتارگاه صنعتی طیور سپیدان آمل',
        'میراب پروفیل',
        'گروه توليدي مهرام',
        'نورد و توليد قطعات فولادي',
        'گلوكوزان',
        'نورد و لوله صفا',
        'مارگارين',
        'نوین آلیاژسمنان',
        'مجتمع صنایع غذایی بهپودر اصفهان',
        'فولاد آذربايجان',
        'مجتمع كشت و صنعت چين چين',
        'فولاد افزا سپاهان',
        'مجتمع کارخانجات سوربن شمال',
        'گروه ملي صنعتي فولاد ايران',
        'مرغ اجداد زربال',
        'پروفيل صنعت جنوب',
        'شوكو پارس',
        'صبا فولاد خلیج فارس',
        'آرد تجارت',
        'فولاد تربت حیدریه',
        'بهپاك',
        'لوله و تجهيزات سديد',
        'پيچك',
        'نورد لوله اهواز',
        'توسعه کشت و صنعت ملی ( كشت و صنعت گرگان )',
        'نورد و پروفيل پارس',
        'فراورده هاي غذائي مشهد',
        'گروه پیمانکاری صنعتی',
        'گروه معادن',
        'احداث صنعت',
        'معدن کاران انگوران',
        'گروه ساخت قطعات خودرو',
        'باما',
        'تولید موتور های دیزل ایران',
        'تامين ماسه ريخته گري',
        'اگزوز خودرو خراسان',
        'تامین مواد اولیه فولاد صبا نور',
        'الكتريك خودرو شرق',
        'توسعه معادن روي ايران',
        'آهنگري تراكتورسازي ايران',
        'توليد فروموليبدن كرمان',
        'اورند پلاستیک',
        'تولیدی آذر سنگ سرخ',
        'ايران دوچرخ',
        'جهاد نصر سیرجان',
        'پلاسكو كار سايپا',
        'حفاری ایراندشت کاشان',
        'توليد محورخودرو',
        'ذوب وروی بافق',
        'توليدي قطعات محوري خراسان',
        'زرین معدن آسیا',
        'تولیدی صنعتی لنت پارس',
        'زغال سنگ نگين طبس',
        'چرخشگر',
        'زنجان برنز',
        'رادياتور ايران',
        'سرمایه گذاری توسعه معادن کوثر',
        'ريخته گري تراكتورسازي ايران',
        'سنگ آهن شرق',
        'رينگ سازي مشهد',
        'سنگ آهن گل گهر',
        'ریخته گری آلومینیوم ایران خودرو',
        'سنگاب آذرشهر',
        'ساخت و نصب صنعتی البرز',
        'سنگاب همدان',
        'سازه پويش',
        'سوژميران',
        'سايپا آذين',
        'سولفاتيک',
        'سایپا پرس',
        'شن سازان هراز',
        'سیبا موتور',
        'صنعت روی زنگان',
        'شمیم پژوهش',
        'صنعتي و معدني شمال شرق شاهرود',
        'صنايع ريخته گري ايران',
        'فراوري مواد معدني ايران',
        'صنایع ریخته گری پرلیت آسیا',
        'فرو سيليس ايران',
        'صنایع نوید موتور',
        'مجتمع معادن سنگ چینی نی ریز',
        'صنعتي نيرو محركه',
        'معادن بافق',
        'صنعتی صبوران پلیمر',
        'معادن سنگ اهن احیاء سپاهان',
        'فنر سازی زر گلپايگان',
        'معادن منگنز ايران',
        'فنرسازي خاور',
        'معدن کار باختر',
        'فنرسازي زر',
        'معدني دماوند',
        'كاربراتور ايران',
        'معدني و صنعتي چادرملو',
        'كارخانجات كمك فنر ايندامين سايپا',
        'معدنی و فرآوری سرمه فیروزآباد',
        'کابل خودرو سبزوار',
        'ندای رهاوی',
        'کلاچ سازی شایان صنعت',
        'زغال سنگ البرز شرقی',
        'گیربکس سایپا',
        'زغال سنگ البرز مرکزی',
        'لنت ترمز ايران',
        'زغال سنگ کرمان',
        'ماشین سازی فراگیر سپنتا',
        'فرآوري معدني اپال کاني پارس',
        'مجتمع صنعتی سپاهان باطری',
        'گروه توسعه معادن روی ایران',
        'محورسازان ايران خودرو',
        'گروه قند و شکر',
        'مهركام پارس',
        'سهامی عام شهد – قند خوی',
        'مهندسي نصير ماشين',
        'شکر شاهرود',
        'موتورسازان تراكتورسازي ايران',
        'صنعتی کشاورزی شیرین خراسان',
        'نیروسازاراک‎',
        'فرآورد ه هاي غذايي و قند پيرانشهر',
        'یسکو',
        'فراورده هاي غذايي و قند تربت جام',
        'گروه انتشار، چاپ و تكثير',
        'فرآورده هاي غذايي و قند چهارمحال',
        'افست',
        'قند اصفهان',
        'گروه خدمات فنی و مهندسی',
        'قند ثابت خراسان',
        'ملی ساختمان',
        'قند شيروان قوچان وبجنورد',
        'مهندسی فرا نیرو',
        'قند قهستان',
        'آبادراهان پارس',
        'قند لرستان',
        'احداث تاسیسات انتقال نیرو – اتانیر',
        'قند مرودشت',
        'آذرپاسیلو',
        'قند نقش جهان',
        'ارسا ساختمان',
        'قند نيشابور',
        'آفرینه طوس',
        'قند هكمتان',
        'اهرام فناوری قدرت',
        'کارخانجات قند قزوین',
        'ایریتک',
        'قند بيستون',
        'بازرسي مهندسي و صنعتي ايران',
        'قند پارس',
        'تجهیزات و خدمات صنایع آب و برق ایران – صانیر',
        'گروه رایانه و فعالیتهای وابسته به آن',
        'تکنیک',
        'ایران ارقام',
        'توسعه ساخت و نصب صنايع بتني و فلزي گسترش مانا ساز آبيک',
        'تجارت الكترونيك پارسيان',
        'جنرال مکانیک',
        'توسعه سازه پایه فن آوا',
        'حفاری شمال',
        'توسعه فناوری اطلاعات خوارزمی',
        'خدمات مهندسی ساختمان تاسیسات راه آهن',
        'تینا سامانه',
        'خدماتي تجهيزات سنگين همگام',
        'داده پردازي خوارزمي',
        'راهبران فولاد اصفهان',
        'داده پردازی ایران',
        'راهسازی و ساختمانی 115',
        'داده پردازی فن آوا',
        'ره  گستر نفت',
        'داده سامانه فن آوا',
        'صنعتی دریایی ایران – صدرا',
        'فن آوا کارت',
        'فراب',
        'کارت اعتباری ایران کیش',
        'کیسون',
        'گسترش الکترونیک مبین ایران',
        'معماران پارس صنعت',
        'خدمات انفورماتیک',
        'مهام شرق',
        'گروه وسايل اندازه گيري، پزشكي و اپتيكي',
        'مهندسان مشاور سازه',
        'مهندسی فرسار تجارت',
        'مهندسي و نصب فيرمکو پارس',
        'پویندگان راه سعادت',
        'مهندسي وتحقيقاتي فلزات غيرآهنی',
        'كنتور سازي ايران',
        'مهندسی و پشتیبانی نیروگاهی البرز توربین',
        'گروه ماشين آلات و تجهيزات',
        'موننکو ایران',
        'مارال صنعت جاوید',
        'نصب نیرو',
        'ماشین رول',
        'خدمات ماشینی کشتیرانی',
        'افرند کالا سازه',
        'گسترش صنايع وخدمات',
        'آلفا پاک ایران',
        'گروه لوازم خانگي',
        'بلبرينگ ايران',
        'لعران',
        'بهسازان غلطک فولاد اصفهان',
        'ارج',
        'پارس بوشونگ',
        'آیسان خزر',
        'پاریزان صنعت',
        'پارس خزر',
        'پمپ سمنان انرژی',
        'تولیدی و صنعتی نیک کالا',
        'تراكتور سازي ايران',
        'صنايع سرماآفرين قشم',
        'تراکتور سازی کردستان',
        'صنعتي جنرال',
        'تسهیل ماشین صنعت',
        'كارخانجات آبسال',
        'توليد تجهيزات سنگين هپكو',
        'كارخانجات لوازم خانگي پارس',
        'توليدي پمپ پارس',
        'کارخانجات پارس ماشین',
        'توليدي تجهيزات ايمني راهها',
        'گروه صنعتي بوتان',
        'تیراژه ماشین',
        'لوازم خانگی نانیوا',
        'دلتا راه ماشین',
        'توليدي كولر گازي ايران',
        'رهشاد سپاهان',
        'جام جهان نما',
        'ساخت تجهيزات سپاهان',
        'كارخانجات صنعتي آزمايش',
        'سوت ماشین',
        'گروه پلاستيك',
        'صنايع پمپ سازي ايران',
        'یزد بسپار',
        'صنايع سرما آفرين',
        'آرتا پلاست',
        'صنایع پمپ ابارا',
        'پلاستيران',
        'صنعتی هلی خودرو',
        'پلاستيکهاي مهندسي درخشان ساز',
        'طراحي مهندسي وساخت تجهيزات وابزارآلات سايپا',
        'توليدي پلاستيك شاهين',
        'فولادريزي قائم سپهر سپاهان',
        'توليدي گاز لوله',
        'کالای پمپ',
        'توليدي و صنعتي درخشان تهران',
        'ماشين سازي اراك',
        'جوی گستر نفت',
        'ماشين سازي نیرو محركه',
        'صنايع لاستيك سهند',
        'مهندسي تكنو تار',
        'كارخانجات توليدي تهران',
        'مهندسي و توليد ماشين آلات راهسازي و معدني کشاورزي هپکو اراک',
        'توليدي وصنعتي ايران وغرب',
        'مهندسي و ساختمان ماشين سازي اراک',
        'لوله سازي اهواز',
        'مهندسي و قطعات ماشين آلات راه سازي ايران',
        'گروه مبلمان و مصنوعات ديگر',
        'مهندسی فیروزا',
        'عايق پلاستيك',
        'مهندسی و ساخت بویلر مپنا',
        'تجهيزات مدارس ايران',
        'هوا ابزار تهران',
        'صنعتی جهان چیدمان-جلیس',
        'اشتهاد موتورز',
        'گروه محصولات شيميايي',
        'كارخانجات صنعتي  و توليدي اتمسفر',
        'احسان شیمی استهبان',
        'كمپر سور سازي ايران',
        'آریا رزین',
        'ليفتراك سازي سهند',
        'الکترو زر سازه',
        'فرتاک ماشین',
        'ایمن تاش سپاهان',
        'کمباین سازی ایران',
        'بردار شیب',
        'ماشين آلات صنعتي تراكتور سازي ايران',
        'بين المللي محصولات پارس',
        'صنايع توليدي اشتاد ايران',
        'بين المللي سارنگ تدارك',
        'پروفيل و يخچال ايران پويا',
        'پارس زئولايت',
        'توليدي بهمن',
        'پارسیان پارت پاسارگاد',
        'گروه محصولات كاغذي',
        'پاكسان',
        'بسته بندي پارس',
        'پاکنام',
        'صنايع كاغذ سازي كاوه',
        'پالایش قطران ذغالسنگ اصفهان',
        'صنایع چوب و کاغذ مازندران',
        'توکا رنگ فولاد سپاهان',
        'كارتن البرز',
        'تولي پرس',
        'كارتن ايران',
        'توليد سموم علف كش',
        'کارتن مشهد',
        'تولید مواد اولیه الیاف مصنوعی',
        'محصولات کاغذی لطیف',
        'تولیدی و صنعتی  فراسان',
        'كارتن پارس',
        'تولیدی و صنعتی سامد',
        'گروه منسوجات',
        'تولیدی وصنعتی خودرنگ',
        'ايران برك',
        'حباب کف توس',
        'توليدي بافت آزادي',
        'داروئي ارايشي وبهداشتي مينو',
        'وطن اصفهان',
        'دنیای آرایش',
        'ريسندگي و با فندگي كاشان',
        'دوده صنعتي پارس',
        'ريسندگي و بافندگي پاكريس',
        'رزیتان',
        'ريسندگي و بافندگي ري',
        'ریف ایران',
        'فرش پارس',
        'سامان شیمی',
        'گردباف يزد',
        'سرمايه گذاري صنايع شيميايي ايران',
        'گروه صنعتي نقش ايران',
        'شيمي بافت',
        'نساجي بابكان',
        'شيميايي پارس پامچال',
        'نساجي خوي',
        'شيميايي فرآورد قشم',
        'نساجي غرب',
        'شیمیایی بهداد',
        'نساجي قائم شهر',
        'شیمیایی بهداش',
        'نساجي مازندران',
        'شیمیایی و تولیدی رزپلیمر',
        'وطن اصفهان',
        'صنايع شيميايي رنگين',
        'يزد باف',
        'صنايع شيميايي سينا',
        'صنايع نساجي ايران',
        'صنايع شيميايي فارس',
        'گروه بانك ها، موسسات اعتباري و ساير نهادهاي مالي',
        'صنایع بهداشتی ساینا',
        'بانك اقتصاد نوين',
        'صنایع رنگ و رزین طیف سایپا',
        'بانك پارسيان',
        'صنایع شیمی ساختمان آباد گران',
        'بانك سامان',
        'فراپاکس شیراز',
        'بانك كارآفرين',
        'كربن ايران',
        'بانک انصار',
        'كف',
        'بانک ایران زمین',
        'کلر پارس',
        'بانک پاسارگاد',
        'گلتاش',
        'بانک تجارت ایران',
        'لابراتوارهای داروهای گیاهی طبیعت زنده',
        'بانک حکمت ایرانیان',
        'لعاب مشهد',
        'بانک دی',
        'لعابيران',
        'بانک سرمایه',
        'مجتمع صنایع شیمیایی پلیمر ایران',
        'بانک سینا',
        'مديريت صنعت شوينده توسعه صنايع بهشهر',
        'بانک شهر',
        'مروارید هامون',
        'بانک صادرات ایران',
        'معدني املاح ايران',
        'بانک گردشگری',
        'ملي شيمي كشاورز',
        'بانک ملت',
        'من',
        'پست بانک',
        'نيرو كلر',
        'بانک تات',
        'الياف',
        'بانک کشاورزی',
        'پارسيلون',
        'گروه واسطه گري هاي مالي',
        'توليدي  الياف پلي  پروپيلين  بنياد',
        'رايان سايپا',
        'صنايع تبديلي گلستان',
        'سپرده گذاری مرکزی اوراق بهادار و تسویه وجوه',
        'كارخانجات توليدي سوپر رنگ',
        'ليزينگ آريادانا',
        'صنايع رنگ پارس الوان',
        'ليزينگ ايران',
        'گروه مواد و محصولات دارويي',
        'ليزينگ خودرو غدير',
        'آفا شیمی',
        'ليزينگ صنعت و معدن',
        'البرز دارو',
        'ليزينگ ماشين الات سنگين ايرانيان',
        'ايران دارو',
        'لیزینگ اقتصاد نوین',
        'پارس دارو',
        'لیزینگ رازی',
        'تحقیقاتی و تولیدی سیناژن',
        'لیزینگ ماشین آلات و تجهیزات پاسارگاد',
        'تهران دارو',
        'لیزینگ ایرانیان',
        'تهران شيمي',
        'لیزینگ شهر – لیزینگ سامان آریا',
        'توليد ژلاتين کپسول ايران',
        'گروه توزیع برق',
        'توليد مواد اوليه دارو پخش',
        'توزیع برق بوشهر',
        'تولید مواد دارویی درسا دارو',
        'توسعه برق شمال افشان گستر',
        'داروسازي اسوه',
        'صنايع برق زنگان پارس',
        'داروسازي اكسير',
        'گهر انرژي سيرجان',
        'داروسازي امين',
        'برق و انرژی صبا',
        'داروسازي جابرابن حيان',
        'گروه شرکتهای بازرگانی',
        'داروسازي حكيم',
        'اتصال استیل هما',
        'داروسازي دكتر عبيدي',
        'اسپرلوس اهورا',
        'داروسازي روزدارو',
        'افزار پرداز رمیس',
        'داروسازي زهراوي',
        'الهام بیسان',
        'داروسازي فارابي',
        'ایمان تجارت روشن',
        'داروسازي كوثر',
        'بازرگاني پتروشيمي',
        'داروسازی بهوزان',
        'بازرگانی ارمغان مهر سیرت',
        'داروسازی تولید دارو – سهامی خاص',
        'بازرگانی ایران ترانسفو',
        'داروسازی دانا',
        'بازرگانی بین المللی استوان سپند',
        'داروسازی شهید قاضی تبریز',
        'بازرگانی پارس ماهان آسیا',
        'داروسازی گیلارانکو',
        'بازرگانی پتروشیمی زنجان',
        'داروئي و بهداشتي لقمان',
        'بازرگانی تبادل و تدارک کالا',
        'داملران',
        'بازرگانی صبا بیمه ایرانیان',
        'سينا دارو',
        'بازرگانی مبین تجارت غرب',
        'شيمي دارويي داروپخش',
        'بازرگانی نفت یاب',
        'صنعتي كيميدارو',
        'بازرگانی،صنعتی بهشت پارس',
        'فارما شیمی',
        'بهترین های پزشکی پارس',
        'فراورده هاي تزريقي ايران',
        'پارس بازرگان',
        'كارخانجات دارو پخش',
        'پارس گستر مینو',
        'لابراتورهای دارویی رازک',
        'پديده گستران غرب',
        'مواد اولیه دارویی تهران شیمی',
        'تجارت گستران خوارزمي',
        'داروسازی سبحان انکولوژی',
        'تجاری و بازرگانی مواد معدنی میناب',
        'سرمايه گذاري البرز',
        'تجهیز یاران',
        'شيرين دارو',
        'تهیه و تولید خاک نسوز استقلال آباده',
        'گروه دارویی سبحان',
        'توسعه صنايع غذايي بم',
        'گروه خودروسازی',
        'توسعه و تجارت بین المللی صبا',
        'ايران خودرو',
        'توسعه و تجارت ماتریس',
        'ايران خودروديزل',
        'جهان فعالیت',
        'ایران خودرو تبریز',
        'خشکبار دست چین',
        'ایران خودرو خراسان',
        'داده های رسا',
        'ایران خودرو مازندران',
        'دانیال کار',
        'بهمن دیزل',
        'درمان یار آنی',
        'پارس خودرو',
        'راسن درمان',
        'تولیدی و صنعتی عقاب افشان',
        'رویال پیشگام شرق',
        'زامياد',
        'سامان بارز',
        'سايپا',
        'سیاحان سپهر آسیا',
        'سايپاديزل',
        'صخره سنگی فرزین',
        'سایپا کاشان',
        'صنایع نئون پرس',
        'گروه بهمن',
        'فانوس دشت تجارت',
        'بنيان ديزل',
        'کیا مهستان',
        'توليدي مرتب',
        'کیمیا آرا هرم',
        'گروه محصولات لبني',
        'گسترش تجارت کالای ایرانیان',
        'پاک پی',
        'مديريت و ساخت طرحهاي نفت گستر',
        'تولید فرآورده های لبنی کاله',
        'مهر اسپند پویا',
        'شير پاستوريزه پگاه اصفهان',
        'مهندسی بازرگانی درداران سریر',
        'شير پاستوريزه پگاه خراسان',
        'نویان بسپار',
        'شير پگاه آذربايجان غربي',
        'نیکان شهد بارز',
        'صنايع شير ايلام زاگرس',
        'گروه هولدینگ',
        'فراورده هاي لبني پاکسار ساري',
        'توسعه صنايع بهشهر – هلدينگ',
        'لبنيات پاستوريزه پاك',
        'داروپخش – هلدينگ',
        'لبنيات كالبر',
        'راه آهن جمهوری اسلامی ایران',
        'لبنیات پاستوریزه پاک آرا سنندج',
        'سرمايه گذاري توسعه معادن و فلزات',
        'گروه منسوجات و فرش بافی',
        'سرمايه گذاري توكا فولاد – هلدينگ',
        'ابهر ریس',
        'سرمايه گذاري صنعت نفت – هلدينگ',
        'ايران پوپلين',
        'سرمایه گذاری گروه صنعتی ملی',
        'ايران مرينوس',
        'گروه صنعتي سديد – هلدينگ',
        'بافتینه',
        'گروه صنعتي قطعات اتومبيل ايران',
        'پشمبافي توس',
        'گروه صنعتي ناب',
        'پلي اكريل ايران',
        'گسترش نفت و گاز پارسیان',
        'تمدن فرش کاشان',
        'مدیریت پروژه های نیروگاهی ایران – مپنا',
        'تولیدی پارس دکور',
        'هلدینگ توسعه معادن و صنایع معدنی خاورمیانه',
        'تولیدی پارس نخ',
        'هلدینگ دامپروری شیروگوشت پارس',
        'تولیدی پینک',
        'سرمايه گذاري بانك ملي ايران – هلدينگ',
        'تولیدی و صنعتی پارس تکمیل',
        'صنعتي بهشهر',
        'تولیدی و صنعتی رسول اصفهان',
        'گروه بنادر ودریانوردی',
        'شبنم باف',
        'پایانه ها و مخازن پتروشیمی',
        'صنایع موکت همدان',
        'خدمات دریایی و بندری کاوه',
        'صنایع نخ خمین',
        'گروه گاز',
        'صنایع نساجی همدانیان',
        'گاز اصفهان',
        'ظریف مصور',
        'ملی گاز',
        'فرش مشهد',
        'گاز خراسان جنوبی',
        'فرش نگین مشهد',
        'گروه آشامیدنی ها',
        'کارخانجات ریسندگی نطنز',
        'آب معدنی دماوند',
        'مخمل و ابريشم كاشان',
        'آذر شهد ارومیه',
        'موکت نگین مشهد',
        'بهنوش ايران',
        'نساجي بروجرد',
        'پیمان فردان',
        'نساجی کویر سمنان',
        'تولیدی نوشابه ارم نوش',
        'صنايع نساجي ايران',
        'زمزم آذربایجان',
        'گروه حمل و نقل دریایی و حمل و نقل آب های ساحلی',
        'زمزم اصفهان',
        'حمل و نقل ترکیبی کشتیرانی جمهوری اسلامی',
        'زمزم تهران',
        'حمل و نقل خدمات دریایی آبادان',
        'زمزم رشت',
        'خدمات دریایی و کشتیرانی خط دریا بندر',
        'زمزم گرگان',
        'دريابان جنوب ايران',
        'شهداب',
        'کشتیرانی آریا',
        'فرآورده های نوشیدنی تسنیم نوش',
        'کشتیرانی جمهوری اسلامی ایران',
        'نوش مازندران',
        'کشتیرانی والفجر',
        'ساسان',
        'گروه خدمات فنی-مهندسی خودرو',
        'گروه تایر سازی',
        'امداد خودرو ایران',
        'ایران یاسا',
        'امداد خودرو سایپا',
        'بید وایر ایران',
        'بازرسی فنی و کنترل خوردگی تکین کو',
        'توليدي ايران تاير',
        'گواه',
        'توليدي لاستيکهاي صنعتي مبارکه',
        'مزدا یدک',
        'کویر تایر',
        'مهندسی و مشاور سازه گستر سایپا',
        'لاستيك دنا',
        'خدمات کمات ماشین شرق',
        'لاستیک بارز',
        'گروه فرهنگی و گردشگری',
        '8',
        'لاستیک پارس',
        'تجارت توسعه گردشگري آتيه انديشان',
        'مجتمع صنايع لاستيك يزد',
        'توسعه گردشگري کاروانسراي پارس',
        'مجتمع صنعتي آرتاويل تاير',
        'گروه سرمايه گذاري ميراث فرهنگي و گردشگري ايران',
        'توليدي لاستيك البرز – كيان تاير',
        'مجتمع توريستي، رفاهي آبادگران ايران',
        'گروه شرکتهای مشاوره',
        'گروه كاني های غير فلزي',
        'irpmc',
        'آجر نسوز امين آباد',
        'بودجه irpmc',
        'آذريت',
        'همکاران سیستم اردبیل',
        'ايتالران',
        'همکاران سیستم البرز',
        'ايرانيت',
        'همکاران سیستم پناه شرق',
        'پرمیت',
        'همکاران سیستم خراسان جنوبی',
        'پشم شیشه ایران',
        '7',
        'همکاران سیستم خراسان رضوی',
        'تولیدی و صنعتی آبگینه',
        'همکاران سیستم خوزستان',
        'خاك چيني ايران',
        'همکاران سیستم زنجان',
        'زرین شیشه مرکزی',
        'همکاران سیستم فارس',
        'سایپا شیشه',
        'همکاران سیستم قزوین',
        'سراميك هاي صنعتي اردكان',
        'همکاران سیستم گیلان',
        'شيشه قزوين',
        'همکاران سیستم مازندران',
        'شيشه همدان',
        'گروه ماشين آلات و دستگاههاي برقي',
        'شيشه و گاز',
        'ايران ترانسفو',
        'شیشه داروئی رازی تاکستان',
        'ایران ترانسفوی ری',
        'فارسيت اهواز',
        'پارس سوئيچ',
        'فرآورده هاي نسوز پارس',
        'تال ایران',
        'فرآورده هاي نسوزآذر',
        'تامین تابلو',
        'فراورده های نسوز ایران',
        'تجهیزات انتقال برق پارس',
        'كارخانجات توليدي شيشه دارويي رازي',
        'ترانسفور ماتور توزیع زنگان',
        'كارخانه فارسيت درود',
        'تهران پادنا',
        'ورزيران',
        'توربوژنراتور شاهرود',
        'مقره سازی ایران',
        'توس فیوز',
        'چینی سازی البرز',
        'جابون',
        'گروه ارتباطات',
        'خیام الکتریک',
        'ارتباطات فن آوا',
        'صنايع جوشكاب يزد',
        'ارتباطات کوه نور',
        'صنایع کابل سازی افق البرز',
        'ارتباطات سیار ایران – همراه اول',
        'صنعتی مهندسی پالایش نیرو',
        'مخابرات ایران',
        'فاراتل',
        'گروه شرکت های پخش',
        'كابل البرز',
        'پخش سراسری کالای کالبر',
        'كابل باختر',
        'پخش هجرت',
        'كابلهاي مخابراتي شهيد قندي',
        'توزيع داروهاي دامي داروپخش',
        'كارخانجات كابلسازي ايران',
        'مهندسي و پشتيباني پخش فرآورده هاي نفتي امين',
        'کابل تک',
        'گروه بیمه',
        'لامپ پارس شهاب',
        'بيمه پاسارگاد',
        'مازی نور',
        'بیمه آسیا',
        'مهندسی مپنا مکو',
        'بیمه البرز',
        'مهندسی و ساخت توربین مپنا توکا',
        'بیمه پارسیان',
        'مهندسی و ساخت ژنراتور مپنا – پارس',
        'بیمه دانا',
        'موتوژن',
        'بیمه دی',
        'نيرو ترانس',
        'بیمه نوین',
        'پارس نور الکتریک',
        'صندوق بیمه سرمایه گذاری فعالیت های معدنی',
        'توليدي قوه پارس',
        'گروه سرمايه گذاري ها',
        'مهندسی و ساخت پره توربين مپنا – پرتو',
        'حفیظ سامانه',
        'تامین قطعات و تجهیزات سرو نیرو شیراز',
        'تکادو',
        'صنایع مهتاب خراسان',
        'سرمايه گذاري آتيه دماوند',
        'صنعتي مهر آباد',
        'سرمايه گذاري انديشه محوران',
        'گروه كشاورزي ، دامپروري و خدمات وابسته به آن',
        'سرمايه گذاري بهمن',
        'تلیسه نمونه',
        'سرمايه گذاري پارس توشه',
        'دانه چین',
        'سرمايه گذاري توسعه آذربايجان',
        'دامپروری و مرغداری دشت خرمدره',
        'سرمايه گذاري توسعه صنعتي ايران',
        'دامداری شیر و دام بنیاد',
        'سرمايه گذاري توسعه ملي',
        'شیر و گوشت زاگرس',
        'سرمايه گذاري چشم انداز توسعه شمال',
        'کشاورزی ودامپروری بینالود',
        'سرمايه گذاري ساختمان ايران – هلدينگ',
        'کشاورزی ودامپروری دشت نوین ملایرا',
        'سرمايه گذاري سايپا',
        'کشاورزی ودامپروری یاسوج',
        'سرمايه گذاري سپه',
        'کشت و دام قیام اصفهان',
        'سرمايه گذاري صندوق بازنشستگي كشوري',
        'کشت وصنعت سبز پاسارگاد',
        'سرمايه گذاري صنعت بيمه',
        'گسترش صنايع و خدمات کشاورزي',
        'سرمايه گذاري صنعت ومعدن',
        'مجتمع دامداری بیجین',
        'سرمايه گذاري گروه صنايع بهشهر ايران',
        'مجتمع شیر و گوشت مهدشت',
        'سرمايه گذاري گروه صنعتي رنا',
        'مگسال',
        'سرمايه گذاري معيار صنعت پارس',
        'کشت وصنعت پیوند هراز',
        'سرمايه گذاري ملت',
        'گروه محصولات فلزي',
        'سرمايه گذاري ملي ايران',
        'صنعتی گام اراک',
        'سرمايه گذاري نيرو',
        'آریا بارون توس',
        'سرمايه گذاري هامون کيش',
        'پودر جوش ایران',
        'سرمایه گذاری اعتماد جم',
        'تولیدی و صنعتی الکترود یزد',
        'سرمایه گذاری اقتصاد نوین',
        'جوش و اکسیژن ایران',
        'سرمایه گذاری ایساتیس پویا',
        'دژپاد',
        'سرمایه گذاری پارس آریان',
        'سولیران',
        'سرمایه گذاری توسعه و عمران استان اردبیل-سبلان سبز',
        'صنايع مفتولي زنجان',
        'سرمایه گذاری دارویی تامین',
        'صنایع آذرآب',
        'سرمایه گذاری دانایان پارس',
        'صنایع استیل البرز',
        'سرمایه گذاری سروش یاران',
        'صنایع بسته بندی ایران',
        'سرمایه گذاری صندوق بازنشستگی کارکنان بانک ها',
        'صنایع بسته بندی مشهد',
        'گسترش سرمايه گذاري ايران خودرو',
        'صنایع فلزی کوشا',
        'گسترش سرمایه گذاری ایرانیان',
        'صنعتی آما',
        'مديريت سرمايه گذاري اميد',
        'صنعتی جام دارو',
        'نیرو سرمایه',
        'لامیران – تیغ ایران',
        'هلدینگ توسعه معادن و صنایع معدنی خاور میانه -میدکو',
        'آونگان',
        'ملی نفت ایران',
        'پارس متال',
        'مديريت سرمايه برنا',
        'پایساز',
        'سرمايه گذاري بوعلي',
        'توسعه و گسترش صنایع بسته بندی فلزی',
        'سرمايه گذاري سمند',
        'تولیدی ابزار مهدی',
        'سرمايه گذاري صنايع پتروشيمي',
        'گسترش صنایع انرژی آذرآب',
        'سرمايه گذاري كار آفرين',
        'صنایع فلزی ایران',
        'سرمايه گذاري نفت قشم',
        'صنعتی کاوه',
        'سرمایه گذاری پویا همگام',
        'صنعتی ملایر',
        'سرمایه گذاری توسعه  الوند غدیر',
        'بسته بندي البرز',
        'گروه فعاليتهاي پشتيباني و حمل و نقل',
        'گروه حمل و نقل، انبارداری و ارتباطات',
        'خدمات دريايي تايدواترخاورميانه',
        'بنیادبارانداز',
        'گروه توليدات پتروشيمي',
        'توکا ریل',
        'پترو شیمی لاله',
        'حمل و نقل آشنا راه سماء',
        'پتروشيمي آبادان',
        'حمل و نقل بین المللی خلیج فارس',
        'پتروشيمي اراك-پتروشیمی شازند',
        'حمل و نقل پتروشیمی',
        'پتروشيمي اصفهان',
        'حمل و نقل توکا',
        'پتروشيمي شيراز',
        'گروه فرآورده هاي نفتي كك و سوخت هسته اي',
        'پتروشیمی  پردیس',
        'پالايشگاه نفت تبريز',
        'پتروشیمی  زاگرس',
        'پالایش نفت آبادان',
        'پتروشیمی امیرکبیر',
        'پالایش نفت بندر عباس',
        'پتروشیمی بندر امام',
        'پالایش نفت تهران',
        'پتروشیمی بیستون',
        'پالایش نفت لاوان',
        'پتروشیمی تند گویان',
        'پالایشگاه نفت شیراز',
        'پتروشیمی جم',
        'تجهيز نيروي زنگان',
        'پتروشیمی جهرم',
        'خدمات حفاری صنایع نفت',
        'پتروشیمی خارک',
        'نفت ایرانول',
        'پتروشیمی خراسان',
        'نفت بهران',
        'پتروشیمی رجال',
        'نفت پارس',
        'پتروشیمی فن آوران',
        'نگین فخر آذربایجان',
        'پتروشیمی مارون',
        'توسعه نفت وگاز مپنا',
        'پتروشیمی مبین',
        'تولیدی مخازن گاز طبیعی آسیا ناما',
        'صنایع پتروشیمی کرمانشاه',
        'گروه كاشي و سراميك',
        'پتروشيمي اروند',
        'پارس سرام',
        'پتروشيمي برزويه',
        'تولید سرام دیر گداز',
        'پتروشيمي فجر',
        'تولیدی توس چینی',
        'مديريت توسعه صنايع پتروشيمي',
        'تولیدی گرانیت بهسرام',
        'پتروشيمي بوعلي سينا',
        'سرامیک طوس',
        'پتروشيمي بين الملل',
        'صنایع چینی زرین ایران',
        'پتروشيمي خوزستان',
        'صنایع کاشی اصفهان',
        'پتروشيمي پارس',
        'صنایع کاشی تیما',
        'اوره و ؛آمونیک پتروشیمی زنجان',
        'صنایع کاشی نائین',
        'پتروشيمي فسا',
        'صنایع کاشی و سرامیک الوند',
        'پتروشیمی داراب',
        'کارخانجات کاشی و سرامیک حافظ',
        'پتروشیمی سرمایه گذاری ایرانیان',
        'کارخانه چینی ایران',
        'پتروشیمی لردگان',
        'کاشی بیستون',
        'پتروشیمی ممسنی',
        'کاشی پارس',
        'خاک طلایی توس',
        'کاشی تکسرام',
        'شهرک صنعتی پتروشیمی زنجان',
        'کاشی فیروزه مشهد',
        'صنايع پتروشيمي دهدشت',
        'کاشی کرد',
        'صنایع پتروشیمی تخت جمشید',
        'کاشی نیلو',
        'صنایع پتروشیمی زنجان',
        'کاشی و سرامیک سعدی',
        'گروه انبوه سازي، املاك و مستغلات',
        'کاشی و سرامیک سینا',
        'آ س پ',
        'گلسار فارس',
        'آذر توسعه مسکن',
        'گروه شركتهاي چند رشته اي صنعتي',
        'بين المللي توسعه ساختمان',
        'سرمايه گذاري غدير',
        'پارس مسکن خزر',
        'سرمایه گذاری گروه توسعه ملی(سرمایه گذاری بانک ملی ایران',
        'توسعه ساختمان خوارزمي',
        'گروه ساير وسايل حمل و نقل',
        'توسعه صنعت ساختمان غدیرخوزستان',
        'سرمايه گذاري اعتباري ايران',
        'زرین بنا پارسیان',
        'گروه ساخت راديو، تلويزيون و دستگاهها و وسايل ارتباطي',
        'ساختمان اصفهان',
        'آريا الكترونيك ايران',
        'ساختماني برج ناهيد',
        'پارس الكتريك',
        'سامان گستر اصفهان',
        'شهاب',
        'سرمايه گذاري توسعه شهري توس گستر',
        'صنايع مخابراتي راه دور ايران',
        'سرمايه گذاري توسعه وساختماني برج آوران',
        'فن آوران انیاک',
        'سرمايه گذاري ساختمان نوین',
        'كارخانجات صنعتي پيام',
        'سرمايه گذاري شاهد',
        'كارخانجات مخابراتي ايران',
        'سرمايه گذاري و توسعه خوزستان',
        'مرکز ماشینهای اداری ایران',
        'سرمایه گذاری مسکن تهران',
        'گروه محصولات چوبي',
        'سرمایه گذاری مسکن شمال شرق',
        'ایزوفام',
        'شهرسازی و خانه سازی باغ میشه',
        'توليد فيبر ايران',
        'صبا آرمه',
        'صنايع چوب خزر کاسپين',
        'طرح ساختمان پارسا',
        'نئوپان 22 بهمن',
        'عمران و توسعه شاهد',
        'سخت آژند',
        'گروه شرکت های مشاوره تبلیغاتی',
        'موسسه پویندگان توسعه پارس',
        # Source: https://en.wikipedia.org/wiki/List_of_companies_of_Iran
        'شرکت ملی نفت ایران',
        'معادن ایران',
        'سازمان نوسازی',
        'ایران خودرو',
        'امیدان تجارت کیش ',
        'سایپا',
        'مجتمع فولاد مبارکه',
        'بانک پارسیان',
        'بانک سامان',
        'بانک سپه',
        'صنایع پتروشیمی ایران',
        'بانک مسکن',
        'لایف برد پارسه',
        'صنایع پترو شیمی بو علی سینا',
        'فولاد خورستان',
        'ابر موتور',
        'سرمایه‌گذاری بانک ملی',
        'ایران خودرو دیزل',
        'توسعه صنعتی بوشهر',
        'بانک اقتصاد نوین',
        'شرکت زامیاد',
        'صنایع شیر ایران (پگاه)',
        'سرمایه‌گذاری غدیر',
        'ایمیدرو',
        'کارخانجات داروپخش',
        'سایپا دیزل',
        'بانک کارآفرین',
        'معدنی و صنعتی چادرملو',
        'ساخت تأسیسات دریایی ایران',
        'اتکا',
        'گسترش و نوسازی صنایع ایران',
        'تولی‌پرس',
        'هواپیمایی آسمان',
        'سازمان صنایع هوایی ایران',
        'مادیران',
        'پارس آنلاین',
        'شاتل',
        'شرکت مخابرات ایران',
        'ایرانسل',
        'راه‌آهن ایران',
        'هواپیمایی پیام',
        'متروی تهران',
        'شرکت ملی نفت‌کش ایران',
        'پالایش و پخش فراورده‌های نفتی ایران',
        'سازمان انرژی اتمی ایران',
        'صدا و سیما',
        'رجحان',
        'شرکت داده‌پردازی ایران',
        'گروه هتل‌های هما',
        'کیش اورینتال',
        'الک تیک',
    ]

    def company(self):
        return self.random_element(self.company_names)



# coding=utf-8
from __future__ import unicode_literals
from collections import OrderedDict
from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats_female = OrderedDict((
        ('{{first_name_female}} {{last_name_female}}', 0.97),
        ('{{prefix_female}} {{first_name_female}} {{last_name_female}}', 0.015),
        ('{{first_name_female}} {{last_name_female}} {{suffix}}', 0.02),
        ('{{prefix_female}} {{first_name_female}} {{last_name_female}} {{suffix}}', 0.005),
    ))

    formats_male = OrderedDict((
        ('{{first_name_male}} {{last_name_male}}', 0.97),
        ('{{prefix_male}} {{first_name_male}} {{last_name_male}}', 0.015),
        ('{{first_name_male}} {{last_name_male}} {{suffix}}', 0.02),
        ('{{prefix_male}} {{first_name_male}} {{last_name_male}} {{suffix}}', 0.005),
    ))

    formats = formats_male.copy()
    formats.update(formats_female)

    first_names_male = (
        'Adam',
        'Alexander',
        'Alexandr',
        'Aleš',
        'Alois',
        'Antonín',
        'Arnošt',
        'Bedřich',
        'Bohumil',
        'Bohumír',
        'Bohuslav',
        'Břetislav',
        'Dalibor',
        'Daniel',
        'David',
        'Denis',
        'Dominik',
        'Dušan',
        'Eduard',
        'Emil',
        'Erik',
        'Filip',
        'František',
        'Hynek',
        'Igor',
        'Ivan',
        'Ivo',
        'Jakub',
        'Jan',
        'Jaromír',
        'Jaroslav',
        'Jindřich',
        'Jiří',
        'Josef',
        'Jozef',
        'Ján',
        'Kamil',
        'Karel',
        'Kryštof',
        'Ladislav',
        'Leoš',
        'Libor',
        'Lubomír',
        'Luboš',
        'Ludvík',
        'Luděk',
        'Lukáš',
        'Marcel',
        'Marek',
        'Marian',
        'Martin',
        'Matyáš',
        'Matěj',
        'Michael',
        'Michal',
        'Milan',
        'Miloslav',
        'Miloš',
        'Miroslav',
        'Oldřich',
        'Ondřej',
        'Otakar',
        'Patrik',
        'Pavel',
        'Peter',
        'Petr',
        'Přemysl',
        'Radek',
        'Radim',
        'Radomír',
        'Radovan',
        'René',
        'Richard',
        'Robert',
        'Robin',
        'Roman',
        'Rostislav',
        'Rudolf',
        'Samuel',
        'Stanislav',
        'Tadeáš',
        'Tomáš',
        'Vasyl',
        'Viktor',
        'Vilém',
        'Vladimír',
        'Vladislav',
        'Vlastimil',
        'Vojtěch',
        'Vratislav',
        'Václav',
        'Vít',
        'Vítězslav',
        'Zbyněk',
        'Zdeněk',
        'Šimon',
        'Štefan',
        'Štěpán')

    first_names_female = (
        'Adéla',
        'Alena',
        'Alexandra',
        'Alice',
        'Alžběta',
        'Andrea',
        'Aneta',
        'Anežka',
        'Anna',
        'Barbora',
        'Blanka',
        'Blažena',
        'Bohumila',
        'Božena',
        'Dagmar',
        'Dana',
        'Daniela',
        'Danuše',
        'Denisa',
        'Dominika',
        'Drahomíra',
        'Eliška',
        'Emilie',
        'Eva',
        'Františka',
        'Gabriela',
        'Hana',
        'Helena',
        'Ilona',
        'Irena',
        'Iva',
        'Ivana',
        'Iveta',
        'Jana',
        'Jarmila',
        'Jaroslava',
        'Jindřiška',
        'Jitka',
        'Jiřina',
        'Julie',
        'Kamila',
        'Karolína',
        'Kateřina',
        'Klára',
        'Kristina',
        'Kristýna',
        'Květa',
        'Květoslava',
        'Ladislava',
        'Lenka',
        'Libuše',
        'Lucie',
        'Ludmila',
        'Magdalena',
        'Magdaléna',
        'Marcela',
        'Marie',
        'Markéta',
        'Marta',
        'Martina',
        'Michaela',
        'Milada',
        'Milena',
        'Miloslava',
        'Miluše',
        'Miroslava',
        'Monika',
        'Mária',
        'Naděžda',
        'Natálie',
        'Nela',
        'Nikol',
        'Nikola',
        'Olga',
        'Pavla',
        'Pavlína',
        'Petra',
        'Radka',
        'Renata',
        'Renáta',
        'Romana',
        'Růžena',
        'Sabina',
        'Simona',
        'Soňa',
        'Stanislava',
        'Sára',
        'Tereza',
        'Vendula',
        'Veronika',
        'Viktorie',
        'Vladimíra',
        'Vlasta',
        'Věra',
        'Zdenka',
        'Zdeňka',
        'Zuzana',
        'Štěpánka',
        'Šárka',
        'Žaneta')

    first_names = first_names_male + first_names_female

    last_names_male = (
        'Bartoš',
        'Beneš',
        'Blažek',
        'Bláha',
        'Doležal',
        'Dušek',
        'Dvořák',
        'Fiala',
        'Holub',
        'Horák',
        'Hájek',
        'Jelínek',
        'Kadlec',
        'Kolář',
        'Kopecký',
        'Kratochvíl',
        'Krejčí',
        'Král',
        'Kučera',
        'Kříž',
        'Malý',
        'Marek',
        'Mareš',
        'Mašek',
        'Moravec',
        'Novotný',
        'Novák',
        'Němec',
        'Pokorný',
        'Polák',
        'Pospíšil',
        'Procházka',
        'Růžička',
        'Sedláček',
        'Soukup',
        'Svoboda',
        'Urban',
        'Vaněk',
        'Veselý',
        'Vlček',
        'Zeman',
        'Čermák',
        'Černý',
        'Říha',
        'Šimek',
        'Štěpánek',
        'Šťastný')

    last_names_female = (
        'Bartošová',
        'Benešová',
        'Beranová',
        'Blažková',
        'Bláhová',
        'Doležalová',
        'Dušková',
        'Dvořáková',
        'Fialová',
        'Holubová',
        'Horáková',
        'Hájková',
        'Jandová',
        'Jelínková',
        'Kadlecová',
        'Kolářová',
        'Kopecká',
        'Kratochvílová',
        'Krejčová',
        'Králová',
        'Kučerová',
        'Křížová',
        'Machová',
        'Malá',
        'Marešová',
        'Marková',
        'Mašková',
        'Moravcová',
        'Novotná',
        'Nováková',
        'Němcová',
        'Pokorná',
        'Poláková',
        'Pospíšilová',
        'Procházková',
        'Růžičková',
        'Sedláčková',
        'Soukupová',
        'Svobodová',
        'Tichá',
        'Urbanová',
        'Vacková',
        'Vaňková',
        'Veselá',
        'Vlčková',
        'Vávrová',
        'Zemanová',
        'Čermáková',
        'Černá',
        'Říhová',
        'Šimková',
        'Štěpánková',
        'Šťastná')

    last_names = last_names_male + last_names_female

    degrees = ('JUDr.', 'Ing.', 'Bc.', 'Mgr.', 'MUDr.', 'RNDr.')

    prefixes_male = ('pan', ) + degrees

    prefixes_female = ('paní', 'slečna') + degrees

    suffixes = ('CSc.', 'DiS.', 'Ph.D.', 'Th.D.')



# coding: utf-8

from __future__ import unicode_literals

from .. import Provider as DateTimeProvider


class Provider(DateTimeProvider):

    DAY_NAMES = {
        '0': 'poniedziałek',
        '1': 'wtorek',
        '2': 'środa',
        '3': 'czwartek',
        '4': 'piątek',
        '5': 'sobota',
        '6': 'niedziela',
    }

    MONTH_NAMES = {
        '01': 'styczeń',
        '02': 'luty',
        '03': 'marzec',
        '04': 'kwiecień',
        '05': 'maj',
        '06': 'czerwiec',
        '07': 'lipiec',
        '08': 'sierpień',
        '09': 'wrzesień',
        '10': 'październik',
        '11': 'listopad',
        '12': 'grudzień',
    }

    def day_of_week(self):
        day = self.date('%w')
        return self.DAY_NAMES[day]

    def month_name(self):
        month = self.month()
        return self.MONTH_NAMES[month]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from ..en import Provider as AddressProvider


class Provider(AddressProvider):

    city_prefixes = (
        'North',
        'East',
        'West',
        'South',
        'New',
        'Lake',
        'Port',
        'Upper',
        'Lower',
        'High',
        'Mount',
    )

    city_suffixes = (
        'town', 'ton', 'land', 'ville', 'berg', 'burgh',
        'borough', 'bury', 'burn', 'ing', 'port', 'mouth', 'stone', 'ings'
        'mouth', 'fort', 'haven', 'leigh', 'side', 'gate', 'neath', 'side',
        ' Flats', ' Hill',
    )

    building_number_formats = ('%##', '%#', '%')

    street_suffixes = (
        # Most common:
        'Arcade', 'Arcade', 'Arcade',
        'Avenue', 'Avenue', 'Avenue', 'Avenue',
        'Avenue', 'Avenue', 'Avenue', 'Avenue',
        'Beach Road', 'Beach Road', 'Beach Road', 'Beach Road',
        'Crescent', 'Crescent', 'Crescent', 'Crescent', 'Crescent',
        'Drive', 'Drive', 'Drive', 'Drive',
        'Mews', 'Mews', 'Mews',
        'Place', 'Place', 'Place', 'Place',
        'Range Road', 'Range Road',
        'Road', 'Road', 'Road', 'Road', 'Road', 'Road', 'Road', 'Road', 'Road',
        'Street', 'Street', 'Street', 'Street', 'Street', 'Street', 'Street',
        'Street', 'Street', 'Street', 'Street', 'Street', 'Street', 'Street',
        'Street', 'Street', 'Street', 'Street', 'Street', 'Street', 'Street',
        'Terrace', 'Terrace', 'Terrace',
        'Way', 'Way', 'Way',

        # Other:
        'Access', 'Alley', 'Alleyway', 'Amble', 'Anchorage', 'Approach',
        'Broadway', 'Bypass', 'Causeway', 'Centre',
        'Circle', 'Circuit', 'Close', 'Concourse', 'Copse', 'Corner', 'Court',
        'Cove',
        'Crest', 'Cross', 'Crossing',
        'Cutting',
        'Esplanade',
        'Flats',
        'Gardens', 'Grove', 'Heights', 'Highway',
        'Lane', 'Line', 'Keys',
        'Parade', 'Park', 'Pass',
        'Plaza',
        'Point', 'Quay',
        'Reserve',
        'Ridge',
        'Rise',
        'Square',
        'Track', 'Trail',
        'View',
    )

    # Māori nouns commonly present in placenames.
    te_reo_parts = (
        'ara',
        'awa',
        'horo',
        'kawa',
        'koro',
        'kowhai',
        'manawa',
        'mata',
        'maunga',
        'moko',
        'motu',
        'ngauru',
        'pa'
        'papa',
        'po',
        'puke',
        'rangi',
        'rohe',
        'rongo',
        'roto',
        'tahi',
        'tai',
        'tangi',
        'tau',
        'tere',
        'tipu',
        'wai',
        'waka',
        'whaka',
        'whanga',
        'whare',
        'weka',
    )

    # Māori endings (usually adjectives) commonly present in placenames.
    te_reo_endings = (
        'hanga',
        'hope',
        'iti',
        'iti',
        'kiwi',
        'makau',
        'nui',
        'nui',
        'nui',
        'nuku',
        'roa',
        'rua',
        'tanga',
        'tapu',
        'toa',
        'whenua',
        'whero',
        'whitu',
    )

    postcode_formats = (
        # as per https://en.wikipedia.org/wiki/Postcodes_in_New_Zealand
        # Northland
        '0%##',
        # Auckland
        '1###',
        '20##',
        '21##',
        '22##',
        '23##',
        '24##',
        '25##',
        '26##',
        # Central North Island
        '3###',
        '4###',
        # Lower North Island
        '50##',
        '51##',
        '52##',
        '53##',
        '55##',
        '57##',
        '58##',
        # Wellington
        '60##',
        '61##',
        '62##',
        '64##',
        '69##',
        # Upper South Island
        '7###',
        # Christchurch
        '80##',
        '81##',
        '82##',
        '84##',
        '85##',
        '86##',
        '88##',
        '89##',
        # Southland
        '90##',
        '92##',
        '93##',
        '94##',
        '95##',
        '96##',
        '97##',
        '98##',
    )

    city_formats = (
        '{{first_name}}{{city_suffix}}',
        '{{last_name}}{{city_suffix}}',
        '{{last_name}}{{city_suffix}}',
        '{{last_name}}{{city_suffix}}',
        '{{last_name}}{{city_suffix}}',
        '{{last_name}}{{city_suffix}}',
        '{{city_prefix}} {{last_name}}{{city_suffix}}',
        '{{te_reo_first}}{{te_reo_ending}}',
        '{{te_reo_first}}{{te_reo_ending}}',
        '{{te_reo_first}}{{te_reo_ending}}',
        '{{te_reo_first}}{{te_reo_ending}}',
        '{{te_reo_first}}{{te_reo_part}}{{te_reo_ending}}',
        '{{te_reo_first}}{{te_reo_part}}{{te_reo_ending}}',
    )

    street_name_formats = (
        '{{first_name}} {{street_suffix}}',
        '{{last_name}} {{street_suffix}}',
        '{{last_name}} {{street_suffix}}',
        '{{last_name}} {{street_suffix}}',
        '{{last_name}}-{{last_name}} {{street_suffix}}',
        '{{te_reo_first}}{{te_reo_ending}} {{street_suffix}}',
        '{{te_reo_first}}{{te_reo_ending}} {{street_suffix}}',
        '{{te_reo_first}}{{te_reo_part}}{{te_reo_ending}} {{street_suffix}}',
    )

    street_address_formats = (
        '{{building_number}} {{street_name}}',
        '{{building_number}} {{street_name}}',
        '{{building_number}} {{street_name}}',
        '{{building_number}} {{street_name}}\nRD {{rd_number}}',
        '{{secondary_address}}\n{{building_number}} {{street_name}}',
        'PO Box {{building_number}}',
    )

    address_formats = (
        "{{street_address}}\n{{city}} {{postcode}}",
    )

    secondary_address_formats = (
        'Apt. %##',
        'Flat %#',
        'Suite %##',
        'Unit %#',
        'Level %',
    )

    def state(self):
        # New Zealand does not have states.
        return ''

    def te_reo_part(self):
        return self.random_element(self.te_reo_parts)

    def te_reo_first(self):
        return self.random_element(self.te_reo_parts).capitalize()

    def te_reo_ending(self):
        return self.random_element(self.te_reo_parts + self.te_reo_endings)

    def city_prefix(self):
        return self.random_element(self.city_prefixes)

    def city_suffix(self):
        return self.random_element(self.city_suffixes)

    def rd_number(self):
        return self.random_element([str(i) for i in range(1, 11)])

    def secondary_address(self):
        return self.numerify(
            self.random_element(
                self.secondary_address_formats))



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats_male = (
        '{{first_name_male}} {{last_name_male}}',
        '{{first_name_male}} {{last_name_male}}',
        '{{first_name_male}} {{last_name_male}}',
        '{{first_name_male}} {{last_name_male}}',
        '{{first_name_male}} {{last_name_male}}',
        '{{first_name_male}} {{last_name_male}}',
        '{{first_name_male}}-{{first_name_male}} {{last_name_male}}',
    )

    formats_female = (
        '{{first_name_female}} {{last_name_female}}',
        '{{first_name_female}} {{last_name_female}}',
        '{{first_name_female}} {{last_name_female}}',
        '{{first_name_female}} {{last_name_female}}',
        '{{first_name_female}} {{last_name_female}}',
        '{{first_name_female}} {{last_name_female}}',
        '{{first_name_female}}-{{first_name_female}} {{last_name_female}}',
    )

    formats = formats_male + formats_female

    first_names_male = (
        'Άγγελος', 'Άνθιμος', 'Άρης', 'Άριστος', 'Έκτορας', 'Έξαρχος', 'Ίκαρος',
        'Ίων', 'Αίας', 'Αβραάμ', 'Αγάπιος', 'Αγαθάγγελος', 'Αγαθοκλής',
        'Αγαθόνικος', 'Αγαμέμνων', 'Αγαπητός', 'Αγγελής', 'Αγησίλαος', 'Αδάμ',
        'Αδαμάντιος', 'Αθανάσιος', 'Αθηναγόρας', 'Αθηνόδωρος', 'Αιμίλιος',
        'Αιμιλιανός', 'Ακρίτας', 'Ακριβός', 'Αλέξανδρος', 'Αλέξιος', 'Αλκιβιάδης',
        'Αμβρόσιος', 'Ανάργυρος', 'Ανέστης', 'Αναγνώστης', 'Ανανίας', 'Αναξαγόρας',
        'Αναστάσιος', 'Ανδρέας', 'Ανδροκλής', 'Ανδρόνικος', 'Ανθούλης', 'Αντίγονος',
        'Αντίπατρος', 'Αντύπας', 'Αντώνιος', 'Απόλλων', 'Απόστολος', 'Αρίσταρχος',
        'Αργύριος', 'Αριστείδης', 'Αριστομένης', 'Αριστοτέλης', 'Αριστοφάνης',
        'Αριστόβουλος', 'Αρτέμης', 'Αρτέμιος', 'Αρχέλαος', 'Αρχιμήδης', 'Ασημάκης',
        'Ασημής', 'Ασκληπιός', 'Αστέριος', 'Αυγέρης', 'Αυξέντιος', 'Αφέντης',
        'Αχιλλέας', 'Αύγουστος', 'Βάιος', 'Βαλάντης', 'Βαλέριος', 'Βαλεντίνος',
        'Βαρδής', 'Βαρθολομαίος', 'Βαρσάμος', 'Βασίλειος', 'Βασίλης', 'Βελισσάριος',
        'Βενέτιος', 'Βενιαμίν', 'Βενιζέλος', 'Βησσαρίων', 'Βικέντιος', 'Βλάσης',
        'Βλάσιος', 'Βλαδίμηρος', 'Βρασίδας', 'Βύρων', 'Γαβριήλ', 'Γαλάτιος',
        'Γαληνός', 'Γαρύφαλλος', 'Γεράσιμος', 'Γεώργιος', 'Γιάννης', 'Γιώργος',
        'Γκίκας', 'Γρηγόριος', 'Δήμος', 'Δίκαιος', 'Δαμασκηνός', 'Δαμιανός',
        'Δανιήλ', 'Δημήτρης', 'Δημήτριος', 'Δημοκράτης', 'Δημοσθένης', 'Δημόκριτος',
        'Διαμαντής', 'Διογένης', 'Διομήδης', 'Διονύσιος', 'Δομήνικος', 'Δράκων',
        'Δρόσος', 'Δωρόθεος', 'Ειρηναίος', 'Ελευθέριος', 'Ελισσαίος', 'Εμμανουήλ',
        'Επαμεινώνδας', 'Ερμής', 'Ερμόλαος', 'Ερρίκος', 'Ερωτόκριτος', 'Ευάγγελος',
        'Ευγένιος', 'Ευδόξιος', 'Ευθύμιος', 'Ευκλείδης', 'Ευμένιος', 'Ευριπίδης',
        'Ευσέβιος', 'Ευστάθιος', 'Ευστράτιος', 'Ευτύχιος', 'Εφραίμ', 'Ζήνων',
        'Ζαφείρης', 'Ζαφείριος', 'Ζαχαρίας', 'Ζηνόβιος', 'Ηλίας', 'Ηρακλής',
        'Ηρόδοτος', 'Ησαΐας', 'Θέμης', 'Θαλής', 'Θεμιστοκλής', 'Θεοδόσης',
        'Θεοδόσιος', 'Θεολόγος', 'Θεοτόκης', 'Θεοφάνης', 'Θεοφύλακτος', 'Θεοχάρης',
        'Θεόδουλος', 'Θεόδωρος', 'Θεόκλητος', 'Θεόπιστος', 'Θεόφιλος', 'Θεόφραστος',
        'Θησεύς', 'Θουκυδίδης', 'Θρασύβουλος', 'Θωμάς', 'Ιάκωβος', 'Ιάσονας',
        'Ιάσων', 'Ιγνάτιος', 'Ιερεμίας', 'Ιερόθεος', 'Ιερώνυμος', 'Ιορδάνης',
        'Ιουλιανός', 'Ιούλιος', 'Ιπποκράτης', 'Ιππόλυτος', 'Ισίδωρος', 'Ισαάκ',
        'Ιωάννης', 'Ιωακείμ', 'Ιωνάς', 'Ιωσήφ', 'Κάρολος', 'Κίμων', 'Καλλίνικος',
        'Κηρύκος', 'Κλέαρχος', 'Κλήμης', 'Κλεάνθης', 'Κλεομένης', 'Κλεόβουλος',
        'Κλεόπας', 'Κομνηνός', 'Κορνήλιος', 'Κοσμάς', 'Κρυστάλλης', 'Κυπριανός',
        'Κυριάκος', 'Κυριαζής', 'Κωνσταντίνος', 'Κύρος', 'Κώστας', 'Λάζαρος',
        'Λάμπρος', 'Λάσκαρης', 'Λέανδρος', 'Λέων', 'Λαέρτης', 'Λαοκράτης',
        'Λαυρέντιος', 'Λεμονής', 'Λεονάρδος', 'Λεωνίδας', 'Λογοθέτης', 'Λουδοβίκος',
        'Λουκάς', 'Λουκιανός', 'Λυκούργος', 'Λύσανδρος', 'Μάριος', 'Μάρκος',
        'Μένανδρος', 'Μίνωας', 'Μαγδαληνός', 'Μακάριος', 'Μαρίνος', 'Μαρτίνος',
        'Ματθαίος', 'Μαυρίκιος', 'Μαυροειδής', 'Μαυρούδης', 'Μαύρος', 'Μεγακλής',
        'Μεθόδιος', 'Μελέτιος', 'Μενέλαος', 'Μερκούριος', 'Μηνάς', 'Μικές',
        'Μιλτιάδης', 'Μιχάλης', 'Μιχαήλ', 'Νέαρχος', 'Νίκανδρος', 'Νίκος', 'Νίκων',
        'Ναθαναήλ', 'Ναπολέων', 'Νεκτάριος', 'Νεοκλής', 'Νεόφυτος', 'Νικήτας',
        'Νικηφόρος', 'Νικόδημος', 'Νικόλαος', 'Ξανθός', 'Ξενοφών', 'Οδυσσέας',
        'Οδυσσεύς', 'Ορέστης', 'Ορφέας', 'Πάρις', 'Πάτροκλος', 'Πέτρος', 'Πίνδαρος',
        'Παναγής', 'Παναγιώτης', 'Πανορμίτης', 'Πανταζής', 'Παντελής',
        'Παντελεήμων', 'Παράσχος', 'Παρασκευάς', 'Πασχάλης', 'Παυσανίας', 'Παύλος',
        'Πελοπίδας', 'Περικλής', 'Πλάτων', 'Πλούταρχος', 'Πολυζώης', 'Πολυκράτης',
        'Πολυχρόνιος', 'Πολύβιος', 'Πολύδωρος', 'Πολύκαρπος', 'Πραξιτέλης',
        'Προκόπιος', 'Προμηθέας', 'Πρόδρομος', 'Πυθαγόρας', 'Πύρρος', 'Ράλλης',
        'Ρήγας', 'Ρίζος', 'Ραφαήλ', 'Ραχήλ', 'Ροδόφλος', 'Ρωμανός', 'Σάββας',
        'Σέργιος', 'Σαμουήλ', 'Σαράντης', 'Σεβαστιανός', 'Σεραφείμ', 'Σιρανούς',
        'Σολομών', 'Σοφοκλής', 'Σπήλιος', 'Σπυρίδων', 'Στέλλιος', 'Στέργιος',
        'Στέφανος', 'Σταμάτης', 'Σταμάτιος', 'Σταύρος', 'Στυλιανός', 'Συμεών',
        'Σωκράτης', 'Σωτήρης', 'Σωτήριος', 'Σόλων', 'Σώζων', 'Τίμων', 'Τίτος',
        'Ταξίαρχος', 'Ταξιάρχης', 'Τζανέτος', 'Τηλέμαχος', 'Τηλεμαχος', 'Τιμολέων',
        'Τιμόθεος', 'Τριαντάφυλλος', 'Τρύφων', 'Τσαμπίκος', 'Υάκινθος', 'Φίλιππος',
        'Φαίδων', 'Φανούριος', 'Φιλήμων', 'Φλοριάντ', 'Φοίβος', 'Φρίξος',
        'Φραγκίσκος', 'Φρειδερίκος', 'Φωκάς', 'Φωκίων', 'Φωτεινός', 'Φώτιος',
        'Χάρις', 'Χαράλαμπος', 'Χαρίλαος', 'Χαρίτος', 'Χρήστος', 'Χρίστος',
        'Χριστιάν', 'Χριστόδουλος', 'Χριστόφορος', 'Χρυσοβαλάντιος', 'Χρυσόστομος',
        'Χρύσανθος', 'Όθων', 'Όμηρος',
    )

    first_names_female = (
        'Άλκηστις', 'Άννα', 'Άρτεμις', 'Έλλη', 'Ήβη', 'Ήλια', 'Ήρα', 'Ίρις',
        'Αγάθη', 'Αγάπη', 'Αγαθή', 'Αγγελική', 'Αγλαΐα', 'Αγνή', 'Αγόρω',
        'Αδαμαντία', 'Αηδόνα', 'Αθανασία', 'Αθηνά', 'Αθηνοδώρα', 'Αικατερίνη',
        'Αιμιλία', 'Ακριβή', 'Αλίκη', 'Αλεξάνδρα', 'Αλεξία', 'Αλκινόη', 'Αλκμήνη',
        'Αμαλία', 'Αμβροσία', 'Αμφιθέα', 'Αμφιτρίτη', 'Ανάργυρη', 'Αναστασία',
        'Ανατολή', 'Ανδριανή', 'Ανδρομάχη', 'Ανδρομέδα', 'Ανδρονίκη', 'Ανθή',
        'Ανθούλα', 'Αννίκα', 'Αντιγόνη', 'Αντωνία', 'Απολλωνία', 'Αποστολία',
        'Αρέθα', 'Αργυρούλα', 'Αργυρώ', 'Αρετή', 'Αριάδνη', 'Αριστέα', 'Αρτεμισία',
        'Αρχοντία', 'Ασημίνα', 'Ασημούλα', 'Ασπασία', 'Αστέρω', 'Αταλάντη', 'Αυγή',
        'Αυγουστίνα', 'Αφέντρα', 'Αφροδίτη', 'Αχιλλεία', 'Βάγια', 'Βέρα', 'Βαγιανή',
        'Βαλάντω', 'Βαλέρια', 'Βαλεντίνα', 'Βαρβάρα', 'Βαρσαμία', 'Βασιλεία',
        'Βασιλική', 'Βεατρίκη', 'Βελισσαρία', 'Βενετία', 'Βερονίκη', 'Βερόνικα',
        'Βησσαρία', 'Βικέντια', 'Βικτωρία', 'Βικτόρια', 'Βιολέτα', 'Βιργινία',
        'Βλασία', 'Βρυσηίς', 'Γαβριέλλα', 'Γαλάτεια', 'Γαλήνη', 'Γαρυφαλλιά',
        'Γενοβέφα', 'Γερακίνα', 'Γερασιμούλα', 'Γεσθημανή', 'Γεωργία', 'Γιαννούλα',
        'Γιασεμή', 'Γιολάντα', 'Γκόλφω', 'Γλαύκη', 'Γλυκερία', 'Γραμματική',
        'Δάφνη', 'Δέσποινα', 'Δήμητρα', 'Δαβιδούλα', 'Δαμασκηνή', 'Δαμιανή',
        'Δανάη', 'Δημούλα', 'Διαλεκτή', 'Διαμάντω', 'Διαμαντούλα', 'Διδώ', 'Δικαία',
        'Διονυσία', 'Δούκισσα', 'Δροσιά', 'Δωροθέα', 'Δόμνα', 'Ειρήνη', 'Ελένη',
        'Ελέσσα', 'Ελεονόρα', 'Ελευθερία', 'Ελισάβετ', 'Ελπίδα', 'Ελπίς',
        'Εμμανουέλα', 'Επιστήμη', 'Ερασμία', 'Ερατώ', 'Εριέτα', 'Εριφύλη',
        'Ερμιόνη', 'Ερωφίλη', 'Ευαγγελία', 'Ευανθία', 'Ευγενία', 'Ευδοκία',
        'Ευδοξία', 'Ευθαλία', 'Ευθυμία', 'Ευλαμπία', 'Ευμορφία', 'Ευπραξία',
        'Ευρυδίκη', 'Ευρύκλεια', 'Ευσεβία', 'Ευσεβεία', 'Ευσταθία', 'Ευστρατία',
        'Ευτέρπη', 'Ευτυχία', 'Ευφροσύνη', 'Εύα', 'Εύκλεια', 'Ζαμπέτα', 'Ζαμπία',
        'Ζαφειρία', 'Ζαχαρένια', 'Ζαχαρούλα', 'Ζηναϊς', 'Ζηνοβία', 'Ζησούλα', 'Ζωή',
        'Ηλέκτρα', 'Ηλιάνα', 'Ηράκλεια', 'Ηώ', 'Θάλεια', 'Θέκλα', 'Θέμις', 'Θέτις',
        'Θαλασσινή', 'Θεανώ', 'Θεμιστόκλεια', 'Θεοδοσία', 'Θεοδούλη', 'Θεοδότη',
        'Θεοδώρα', 'Θεολογία', 'Θεοπίστη', 'Θεοφίλη', 'Θεοφανία', 'Θεοφύλακτη',
        'Θεοχαρούλα', 'Θεόκλεια', 'Θεώνη', 'Θηρεσία', 'Θωμαίς', 'Ιακωβίνα',
        'Ιγνατία', 'Ινώ', 'Ιοκάστη', 'Ιορδανία', 'Ιουλία', 'Ιουλιανή', 'Ιππολύτη',
        'Ισαβέλλα', 'Ισιδώρα', 'Ισμήνη', 'Ιφιγένεια', 'Ιωάννα', 'Ιωσηφίνα', 'Καλή',
        'Καλλίνικη', 'Καλλιρρόη', 'Καλλιρόη', 'Καλλιόπη', 'Καλομοίρα', 'Καλυψώ',
        'Κανέλλα', 'Καρυοφυλλιά', 'Κασσάνδρα', 'Κασσιανή', 'Κατερίνα', 'Κερασιά',
        'Κικιλία', 'Κλαίρη', 'Κλειώ', 'Κλεονίκη', 'Κλεοπάτρα', 'Κλημεντίνη',
        'Κλυταιμνήστρα', 'Κοκκώνα', 'Κομνηνή', 'Κονδυλία', 'Κοραλία', 'Κορνηλία',
        'Κρινιώ', 'Κρυσταλλένια', 'Κυβέλη', 'Κυδωνία', 'Κυπαρισσία', 'Κυπριανή',
        'Κυράτσα', 'Κυριακή', 'Κωνσταντία', 'Κωνσταντίνα', 'Κωστούλα', 'Κόσμια',
        'Λήδα', 'Λαζαρία', 'Λαμπρινή', 'Λασκαρίνα', 'Λαυρεντία', 'Λεμονιά',
        'Λευκοθέα', 'Λεωνιδιά', 'Λεώνη', 'Λητώ', 'Λουίζα', 'Λουκία', 'Λουλουδένια',
        'Λυγερή', 'Λυδία', 'Μάνθα', 'Μάρθα', 'Μαγδαληνή', 'Μακρίνα', 'Μαλαμάτη',
        'Μαλαματένια', 'Μαλβίνα', 'Μαντώ', 'Μαρία', 'Μαρίνα', 'Μαργαρίτα',
        'Μαργιέττα', 'Μαριάνθη', 'Μαριάννα', 'Μαριγώ', 'Μαριλένα', 'Μαρκέλλα',
        'Μαρωτέσα', 'Ματίνα', 'Ματθίλδη', 'Ματρώνη', 'Μαύρα', 'Μελένια', 'Μελέτια',
        'Μελίνα', 'Μελπομένη', 'Μερόπη', 'Μεταξία', 'Μηλιά', 'Μινέρβα', 'Μιράντα',
        'Μιχαέλα', 'Μυρσίνη', 'Μυρτώ', 'Μόσχα', 'Νίκη', 'Ναταλία', 'Ναταλίνα',
        'Ναυσικά', 'Νεκταρία', 'Νερατζιά', 'Νεφέλη', 'Νεόκλεια', 'Νικητία',
        'Νικολέτα', 'Νικολίτσα', 'Νομική', 'Νταίζη', 'Ντανιέλα', 'Ξένη', 'Ξανθή',
        'Ξανθίππη', 'Οδύσσεια', 'Ολύμπια', 'Ουρανία', 'Πέτρα', 'Παγώνα', 'Παναγία',
        'Παναγιώτα', 'Πανδώρα', 'Παντελία', 'Παντούλα', 'Πανωραία', 'Παρέσσα',
        'Παρασκευή', 'Παρθένα', 'Πασχαλιά', 'Παταπία', 'Παυλίνα', 'Πελαγία',
        'Περικλεία', 'Περιστέρα', 'Περσεφόνη', 'Πηγή', 'Πηνελόπη', 'Πιερρίνα',
        'Ποθητή', 'Πολυνίκη', 'Πολυξένη', 'Πολυτίμη', 'Πολυχρονία', 'Πολύβια',
        'Πολύδωρα', 'Πολύμνια', 'Πουλχερία', 'Πούλια', 'Προδρομία', 'Πωλίνα', 'Ρέα',
        'Ραλλία', 'Ρεβέκα', 'Ρεβέκκα', 'Ρεγγίνα', 'Ρηγούλα', 'Ροδάνθη', 'Ροδαμάνθη',
        'Ροδιά', 'Ροδόκλεια', 'Ρουμπίνη', 'Ρούσα', 'Ρωξάνη', 'Ρόζα', 'Σάρρα',
        'Σαββούλα', 'Σαλώμη', 'Σαπφώ', 'Σεβαστή', 'Σεβαστιανή', 'Σελήνη', 'Σεμίνα',
        'Σεραφεία', 'Σμαράγδα', 'Σουλτάνα', 'Σουμέλα', 'Σοφία', 'Σπάρτη',
        'Σπυράννα', 'Σπυριδούλα', 'Στέλλα', 'Σταματίνα', 'Σταυρούλα', 'Στεργιανή',
        'Στεργιαννώ', 'Στεφανία', 'Στυλιανή', 'Συμέλα', 'Συμεωνία', 'Συμεώνη',
        'Σωζούσα', 'Σωτηρία', 'Σωφρονία', 'Ταξιαρχία', 'Τατιάνα', 'Τερψιχόρη',
        'Τζένη', 'Τιμοθέα', 'Τριαντάφυλλη', 'Τριανταφυλλιά', 'Τρισεύγενη',
        'Τρυφωνία', 'Τσαμπίκα', 'Υακίνθη', 'Υβόννη', 'Υπαπαντή', 'Φαίδρα', 'Φανή',
        'Φανουρία', 'Φεβρωνία', 'Φερενίκη', 'Φιλίππα', 'Φιλαρέτη', 'Φιλιππία',
        'Φιλιώ', 'Φιλοθέη', 'Φιλομήλα', 'Φλωρίνα', 'Φλωρεντία', 'Φλώρα', 'Φοίβη',
        'Φραντζέσκα', 'Φρειδερίκη', 'Φρύνη', 'Φωτεινή', 'Χάιδω', 'Χάρη', 'Χαρά',
        'Χαρίκλεια', 'Χαραλαμπία', 'Χιονιά', 'Χλόη', 'Χριστίνα', 'Χριστιάνα',
        'Χριστοδούλα', 'Χριστοφόρα', 'Χριστόφιλη', 'Χρυσάνθη', 'Χρυσή', 'Χρυσαυγή',
        'Χρυσαφένια', 'Χρυσοβαλάντου', 'Χρυσοβαλάντω', 'Χρυσούλα', 'Χρυσόστομη',
        'Όλγα',
    )

    first_names = first_names_male + first_names_female

    last_names_male = (
        'Αβαγιανός', 'Αβραμίδης', 'Αβραμιώτης', 'Αγαλιώτης', 'Αγγελάκος', 'Αγγελής',
        'Αγγελίδης', 'Αγγελίκας', 'Αγγελόπουλος', 'Αγκυρόπουλος', 'Αδαμόπουλος',
        'Αετόπουλος', 'Αθανασάκης', 'Αθανασόπουλος', 'Ακαλίδης', 'Ακριτίδης',
        'Ακριώτης', 'Αλατζάκης', 'Αλαφάκης', 'Αλεξανδρόπουλος', 'Αλεξόπουλος',
        'Αμπατζιάνης', 'Αμπλιάνιτης', 'Αμυγδαλάκης', 'Αναστασάκης', 'Αναστασίου',
        'Αναστασόπουλος', 'Αναστόπουλος', 'Ανδρεανίδης', 'Ανδριανός',
        'Ανδρικόπουλος', 'Ανδριόπουλος', 'Ανδριώτης', 'Ανδρουλάκης',
        'Ανδρουλιδάκης', 'Αντωνάκος', 'Αντωνέας', 'Αντωνίου', 'Αντωνιάδης',
        'Αντωνόπουλος', 'Αξαόπουλος', 'Αξιώτης', 'Αποστολάκης', 'Αποστολίδης',
        'Αποστολακάκης', 'Αποστολόπουλος', 'Αραμπατζής', 'Αργυρής', 'Αργυρίου',
        'Αργυρόπουλος', 'Αρμένης', 'Αρχαυλής', 'Ασαρίδης', 'Ασημακόπουλος',
        'Ασημόπουλος', 'Αυγουστής', 'Αφρουδάκης', 'Βάρσος', 'Βάσσης', 'Βαβουλίδης',
        'Βαβουράκης', 'Βακαλάκης', 'Βακαλής', 'Βαλαβάνης', 'Βαλασίδης', 'Βαλτάς',
        'Βαμβακάς', 'Βανδώρος', 'Βαρακλής', 'Βαρδάκης', 'Βαρσάμης', 'Βασιλάκης',
        'Βασιλείου', 'Βασιλογιάννης', 'Βαχουθιανάκης', 'Βαϊτσόπουλος', 'Βελεντζάς',
        'Βιδαλάκης', 'Βιλδός', 'Βιολάτος', 'Βιτσαξής', 'Βλάχος', 'Βλαχονικολέας',
        'Βλησαρούλης', 'Βολικάκης', 'Βορλόκας', 'Βουτσάς', 'Βουτσελας', 'Βούκας',
        'Βούλγαρης', 'Βούλκος', 'Βούρας', 'Βώσσος', 'Γάτος', 'Γαβριδάκης',
        'Γαλατούλας', 'Γαρουφαλής', 'Γαρυφαλίδης', 'Γενετζάκης', 'Γεννηματάς',
        'Γεντίμης', 'Γεράρδης', 'Γεροδήμος', 'Γερόπουλος', 'Γεωργακόπουλος',
        'Γεωργαλάς', 'Γεωργαλής', 'Γεωργούδης', 'Γεωργούλας', 'Γιαννάκης',
        'Γιαννέλος', 'Γιαννές', 'Γιαννακέας', 'Γιαννακίτσας', 'Γιαννακουδάκης',
        'Γιαννακόπουλος', 'Γιαννούκος', 'Γιαννόπουλος', 'Γιαπατζής', 'Γιασημάκης',
        'Γιατρομανωλάκης', 'Γιωτάκης', 'Γιώτης', 'Γκάγκας', 'Γκίκας', 'Γκίνης',
        'Γκαγκαουδάκης', 'Γκαλίου', 'Γκανάτσιος', 'Γκατζογιάννης', 'Γκικόπουλος',
        'Γκιολδελής', 'Γκιτσάκης', 'Γκουτζαμάνης', 'Γκούβελος', 'Γκούσκος',
        'Γκότσης', 'Γουργουλής', 'Γούσιος', 'Γρίβας', 'Γραμματικόπουλος',
        'Γραμματικός', 'Γρατσιάς', 'Γρεβενάρης', 'Γρετός', 'Γρηγορίου',
        'Γρηγοριάδης', 'Γρηγορόπουλος', 'Δάρας', 'Δέλιος', 'Δίγκας', 'Δακαναλής',
        'Δανέζης', 'Δανελής', 'Δανιηλίδης', 'Δερμιτζάκης', 'Δεσύλλας', 'Δημησκής',
        'Δημητρίου', 'Δημητρόπουλος', 'Δημοβελής', 'Δημόπουλος', 'Διακάκης',
        'Διαμαντής', 'Δινεζάκης', 'Δουβίκας', 'Δουβρόπουλος', 'Δουκάς', 'Δουκατζής',
        'Δουλάμης', 'Δουλγεράκης', 'Δουμάς', 'Δουράνης', 'Δούνης', 'Δραζιώτης',
        'Δρακάκης', 'Δρακόπουλος', 'Δρουλιάς', 'Δόβας', 'Δόσης', 'Ελευθερίου',
        'Εμπορόπουλος', 'Εσπερίδης', 'Ευαγγελάτος', 'Ευαγγελινός', 'Ευκαρπίδης',
        'Ευστρατόπουλος', 'Ευταξιάς', 'Έψιμος', 'Ζαραφέτας', 'Ζαφείρης', 'Ζαχαρίου',
        'Ζενεμπίσης', 'Ζευγίτης', 'Ζηδιανάκης', 'Ζηματίκας', 'Ζηρός', 'Ζιάκας',
        'Ζιώγος', 'Ζολώτας', 'Ζορμπάς', 'Ζουκής', 'Ζουλούμης', 'Ζούνης', 'Ζτούκος',
        'Ζυγούρης', 'Ζώνιος', 'Ζώτος', 'Θεοδοσίου', 'Θεοδωρικάκος', 'Θεοδωρόπουλος',
        'Θεολόγος', 'Θεοχάρης', 'Θηβαίος', 'Θωμάς', 'Θωμόπουλος', 'Ιακωβάκης',
        'Ιατρόπουλος', 'Ιντζές', 'Ισάρης', 'Ισέρης', 'Ιωσηφίδης', 'Κίσσας',
        'Καβούρης', 'Καζανόπουλος', 'Κακαβός', 'Κακατσός', 'Κακοσαίος', 'Καλαμάρας',
        'Καλαμαράκης', 'Καλαμπαλίκης', 'Καλαπόδης', 'Καλαργυρός', 'Καλαϊτζάκης',
        'Καλιάμπος', 'Καλιτσουνάκης', 'Καμπάκας', 'Καμπερίδης', 'Καμποσάκης',
        'Καναβός', 'Κανελλόπουλος', 'Καπατσώρης', 'Καπετάνιος', 'Καπούνης',
        'Καράμπας', 'Καράνης', 'Καραΐσκος', 'Καραγιάννης', 'Καραγρηγορίου',
        'Καραδήμος', 'Καρακάξης', 'Καρακαστανιάς', 'Καρακυρίου', 'Καραλής',
        'Καραμάνος', 'Καραμσαλής', 'Καρανίκας', 'Καρανασίου', 'Καρανικόλας',
        'Καραντζόπουλος', 'Καρατζίκος', 'Καρατζαφέρης', 'Καρούντζος', 'Καρούσος',
        'Καρτάς', 'Καρυπίδης', 'Κασούτσας', 'Καστάνης', 'Κατάκης', 'Καταραχιάς',
        'Κατεβάτης', 'Κατιρτζής', 'Κατσίπης', 'Κατσίφος', 'Κατσαβός', 'Κατσαμάνης',
        'Κατσαντώνης', 'Κατσαρός', 'Κατσιγιάννης', 'Κατσιλής', 'Κατσογιάννης',
        'Καφίρης', 'Καφαντάρης', 'Καψάλης', 'Κελαϊδώνης', 'Κελλάρης', 'Κερασοβίτης',
        'Κεσαλίδης', 'Κεσεμίδης', 'Κεχαγιάς', 'Κιοσές', 'Κιουπλιώτης', 'Κιούσης',
        'Κιτινός', 'Κλήμης', 'Κοκορδέλης', 'Κολοβός', 'Κολοκάθης', 'Κολχούρης',
        'Κομκούδης', 'Κομπολιάς', 'Κονδυλίδης', 'Κονιδάρης', 'Κοντάκος',
        'Κοντογιάννης', 'Κοντοκώστας', 'Κοντός', 'Κορδατζής', 'Κορμπόπουλος',
        'Κορομήλας', 'Κοτσαρής', 'Κοττίκας', 'Κουβάς', 'Κουκλατζής', 'Κουκουβίνος',
        'Κουκουλιάντας', 'Κουλίδης', 'Κουλίζος', 'Κουλουριώτης', 'Κουμιώτης',
        'Κουράκος', 'Κουρής', 'Κουρελής', 'Κουρκουτάς', 'Κουρσάρης', 'Κουρσουμίδης',
        'Κουταλιός', 'Κουτελιέρης', 'Κουτεντάκης', 'Κουτσικόπουλος',
        'Κουτσογιάννης', 'Κουτσογιάννόπουλος', 'Κουτσουλής', 'Κουτσουρέλης',
        'Κουτσούρας', 'Κουτχιάς', 'Κούρτης', 'Κούτρης', 'Κούτσικος', 'Κραββαρίτης',
        'Κρεμμύδας', 'Κριάλης', 'Κριτσέλης', 'Κτενίδης', 'Κυμπάρης', 'Κυπραίος',
        'Κυπριώτης', 'Κυρίτσης', 'Κυργιάκης', 'Κυριαζής', 'Κυριακάκης',
        'Κυριακίδης', 'Κυριατσούλης', 'Κωνσταντάς', 'Κωνσταντακόπουλος',
        'Κωνσταντινίδης', 'Κωνσταντόπουλος', 'Κωστάκης', 'Κωστίδης', 'Κωσταλής',
        'Κωστούλας', 'Κωστόπουλος', 'Κωτούλας', 'Κωτσίδης', 'Κωτσικόρης', 'Κόλκας',
        'Κώττας', 'Λάκκας', 'Λάλας', 'Λάππας', 'Λάτσκος', 'Λέλεκας', 'Λαγγούσης',
        'Λαγογιάννης', 'Λαγοπάτης', 'Λαζαρίδης', 'Λαμπρινός', 'Λαουρδέκης',
        'Λαφατζής', 'Λεβέντης', 'Λελεδάκης', 'Λεμονής', 'Λεντζίου', 'Λιανάκης',
        'Λιβανός', 'Λιθοξοΐδης', 'Λιούτας', 'Λιτίνας', 'Λιόλιος', 'Λουλάκης',
        'Λουπασάκης', 'Λουράντος', 'Λυγκούρας', 'Λυμπέρης', 'Λώλος', 'Μάνδαλος',
        'Μάνδρος', 'Μάνος', 'Μάργαρης', 'Μάρρας', 'Μάστορας', 'Μίσχος', 'Μίχος',
        'Μαγκούφης', 'Μαζαράκης', 'Μακαριάδης', 'Μακρής', 'Μακρυγιάννης',
        'Μακρυκώστας', 'Μαμμής', 'Μανίκας', 'Μανελίδης', 'Μανιώτης', 'Μανουσέλης',
        'Μανουσιάδης', 'Μανούκας', 'Μαντάρης', 'Μαντάς', 'Μαντζουράνης',
        'Μαντζώρος', 'Μανωλάκης', 'Μανωλέας', 'Μαραγκός', 'Μαρακάς', 'Μαργαρώνης',
        'Μαρκόπουλος', 'Μασγαλάς', 'Μαστρογιάννης', 'Μαστρογιώργης', 'Μασόπουλος',
        'Ματσούκας', 'Μαυρικάκης', 'Μαυρογονάτος', 'Μαυροειδάκος', 'Μαυρομανωλάκης',
        'Μαυρομμάτης', 'Μαυρουδής', 'Μαυρούτσος', 'Μελιτσόπουλος', 'Μεταξάς',
        'Μεϊμάρης', 'Μηλιώρης', 'Μητρίδης', 'Μητρόπουλος', 'Μητσόπουλος',
        'Μιχαηλίδης', 'Μιχαλάκης', 'Μιχαλέλλης', 'Μοσχόπουλος', 'Μουσελίμης',
        'Μουτουσίδης', 'Μπέκος', 'Μπίλλας', 'Μπαγανάς', 'Μπακλάβας',
        'Μπακοστεργίου', 'Μπαλάσκας', 'Μπαλουκίδης', 'Μπαλταγιάννης', 'Μπαλτζής',
        'Μπαντές', 'Μπαντής', 'Μπερεδήμας', 'Μπερμπατιώτης', 'Μπλανάς',
        'Μπλιατσίου', 'Μποζίκης', 'Μποτσώλης', 'Μποτώνης', 'Μπουλούκος', 'Μπουρλής',
        'Μποφός', 'Μπούκος', 'Μπούσιος', 'Μπραζιώτης', 'Μπότης', 'Μυλωνάς',
        'Μυσιρλής', 'Μυτελέτσης', 'Μωραΐτης', 'Μωρός', 'Μόκας', 'Μόναχας',
        'Νάστατος', 'Νάστος', 'Νέλος', 'Νανούρης', 'Νασίκας', 'Νασιόπουλος',
        'Νικητόπουλος', 'Νικολαΐδης', 'Νικολόπουλος', 'Νικουλής', 'Νιτσοτόλης',
        'Νούσης', 'Νταβάς', 'Ντουλιάς', 'Ντόβας', 'Ντόκος', 'Ντότης', 'Ξανθάκης',
        'Ξηρογιάννης', 'Ξηρός', 'Ορφανάκης', 'Ορφανιώτης', 'Ότσος', 'Πάγκαλος',
        'Πάνος', 'Πάντος', 'Πέππας', 'Πέτσας', 'Πίππας', 'Πίσσιος', 'Πίτσης',
        'Παλαιολόγος', 'Παληός', 'Παλλάς', 'Παναγιωτακόπουλος', 'Πανδής',
        'Πανούσης', 'Πανταζής', 'Παντζέκος', 'Παντζαρτζίδης', 'Παπαγεωργίου',
        'Παπαγιάννης', 'Παπαγιαννακόπουλος', 'Παπαγιαννόπουλος', 'Παπαδάκης',
        'Παπαδημητράκης', 'Παπαδημητριάδης', 'Παπαδόπουλος', 'Παπαευαγγελίου',
        'Παπαθανασίου', 'Παπαθεοδοσίου', 'Παπαπανός', 'Παπαροϊδάμης', 'Παπαστεργίου',
        'Παπατρέχας', 'Παπαφώτης', 'Παπουδής', 'Παπουλής', 'Παππάς',
        'Παρασκευόπουλος', 'Παργανάς', 'Παρούσης', 'Πασσαλίδης', 'Πατελής',
        'Πατμανίδης', 'Πατσούρας', 'Περάκης', 'Περδίκης', 'Περδικάκης',
        'Περιστερόπουλος', 'Περπινιάς', 'Περράκης', 'Περρώτης', 'Πετράκης',
        'Πετρίδης', 'Πετριτάκης', 'Πετρογιάννης', 'Πετρόπουλος', 'Πευκιανάκης',
        'Πιάγκος', 'Πικούνης', 'Πικρός', 'Πιπεράκης', 'Πιπερίγκος', 'Πισχινάς',
        'Πιτερός', 'Πιτσάκης', 'Πιτσολής', 'Πλακωτάρης', 'Πλιάτσικας', 'Πολυζωάκης',
        'Πολυχρονίδης', 'Πολυχρονόπουλος', 'Πολυχρόνης', 'Πορίχης', 'Πουλημένος',
        'Πουλιέζος', 'Πουλογιαννόπουλος', 'Πουφτσής', 'Προβής', 'Πυλαρινός',
        'Ράλλης', 'Ράπτης', 'Ρέγκας', 'Ρέντας', 'Ρέντζος', 'Ρέππος', 'Ρήγας',
        'Ρήνος', 'Ρίγκος', 'Ρίζος', 'Ρίσβας', 'Ραγκούσης', 'Ραδοβάλης', 'Ραφιός',
        'Ραχμανίδης', 'Ραχωβίτσας', 'Ριζούλης', 'Ρουπακάς', 'Ρουσιανός',
        'Ροϊδούλης', 'Ρωμαίου', 'Ρόγαρης', 'Ρόδης', 'Ρόκας', 'Σάτλας', 'Σίδερης',
        'Σακελλαρίου', 'Σαλίχος', 'Σαλταούρας', 'Σαμακίδης', 'Σαμανίδης', 'Σαμαράς',
        'Σαουλίδης', 'Σαρίκας', 'Σαραντινός', 'Σαραφίδης', 'Σαρρός', 'Σγουρός',
        'Σδραλλής', 'Σεβδάς', 'Σεφέκος', 'Σιγανός', 'Σιδηρόπουλος', 'Σικαλίδης',
        'Σιτόπουλος', 'Σιώμος', 'Σιώρης', 'Σκαρλάτος', 'Σκαρπέτας', 'Σκορδάκης',
        'Σκουλαρίδης', 'Σκρέκας', 'Σκρίμπας', 'Σκόρδος', 'Σμαρδάς', 'Σμπονιάς',
        'Σμπρίνης', 'Σμυρνιώτης', 'Σολακούδης', 'Σουλιντζής', 'Σουρμπής',
        'Σοφιανός', 'Σπάλας', 'Σπαθόπουλος', 'Σπανδωνίδης', 'Σπανουδάκης', 'Σπανός',
        'Σπασόπουλος', 'Σπηλιώτης', 'Σπορδιλής', 'Σπυριδάκης', 'Σπυρόπουλος',
        'Σταθάτος', 'Σταθόπουλος', 'Σταμάτης', 'Σταμέλος', 'Σταματιάδης',
        'Σταμούλης', 'Σταμόπουλος', 'Σταυριανός', 'Σταυρόπουλος', 'Στεργιαλής',
        'Στεργιούδης', 'Στοφοριάδης', 'Στραβοσνίχης', 'Στόγιος', 'Συλλίγαρδος',
        'Συργής', 'Συρρής', 'Σφούνης', 'Σφύρλας', 'Σωτηράλης', 'Σύκας', 'Τάρναρης',
        'Τάσιος', 'Τάχας', 'Ταβερναράκης', 'Τακαντζάς', 'Ταμιωλάκης', 'Τασιούλας',
        'Ταχμαζίδης', 'Ταχτσίδης', 'Τεμουρτζίδης', 'Τερζής', 'Τερζίδης', 'Τζέκος',
        'Τζήκας', 'Τζαβέλλας', 'Τζαλλας', 'Τζανουδάκης', 'Τζεβελέκος', 'Τζιάβας',
        'Τζιάρας', 'Τζινιέρης', 'Τζιόρτζιος', 'Τζιώτζης', 'Τζουβέλης', 'Τζουμάκης',
        'Τοδώρης', 'Τολούδης', 'Τορομίδης', 'Τουρναβίτης', 'Τραχίλης', 'Τρεντσίου',
        'Τριαντακωνσταντής', 'Τριβέλλας', 'Τσάρκος', 'Τσέας', 'Τσέγας', 'Τσέλιος',
        'Τσέλλος', 'Τσαγκρασούλης', 'Τσαγλιώτης', 'Τσακανίκας', 'Τσακμάκης',
        'Τσαλαμάνδρης', 'Τσαμαδός', 'Τσαμασλίδης', 'Τσανδήλας', 'Τσαπραλής',
        'Τσαραμιάδης', 'Τσατσάνης', 'Τσεμπερλίδης', 'Τσεντούρος', 'Τσιάκος',
        'Τσιάρας', 'Τσιαμίτας', 'Τσιαμούρας', 'Τσιαντάς', 'Τσιατής', 'Τσιγαρίδας',
        'Τσικνιάς', 'Τσιρώνης', 'Τσιτούρας', 'Τσομώκος', 'Τσοπανίδης', 'Τσουκνίδας',
        'Τσούμος', 'Τσούπρας', 'Τσόλκας', 'Τσότρας', 'Τσώνης', 'Τσώτσης', 'Τυμβίου',
        'Τυράλης', 'Φαλιέρος', 'Φανουργάκης', 'Φειδερόπουλος', 'Φερεντίνος',
        'Φιλιππάκης', 'Φιλιππάτος', 'Φιλιππόπουλος', 'Φουντζούλας', 'Φουσιέκης',
        'Φουτσιτζής', 'Φούσκας', 'Φραγκόπουλος', 'Φραντζής', 'Φρογάκης', 'Φυδάνης',
        'Φωκάς', 'Φωκαδελής', 'Φωτογλίδης', 'Φωτόπουλος', 'Χέλιος', 'Χαβρεδάκης',
        'Χαλατσής', 'Χαραλάμπους', 'Χαραλαμπίδης', 'Χαρισιάδης', 'Χαρμπίλας',
        'Χαρπαντίδης', 'Χαρτερός', 'Χατζαντώνης', 'Χατζελλής', 'Χατζηβλασίου',
        'Χατζηγεωργίου', 'Χατζηγρηγοράκης', 'Χατζηκύρκος', 'Χατζησάββας',
        'Χατζησαββίδης', 'Χατζησταυράκης', 'Χατζιάρας', 'Χατζόπουλος', 'Χαχούδης',
        'Χητός', 'Χιτός', 'Χονδρολίδης', 'Χουδαλάκης', 'Χουλιάρας', 'Χουντής',
        'Χουχουλής', 'Χριστάκης', 'Χριστάρας', 'Χριστακόπουλος', 'Χριστοδουλάκης',
        'Χριστόπουλος', 'Χρονόπουλος', 'Χρυσίδης', 'Χρυσικός', 'Χρυσοβέργης',
        'Χρυσουλής', 'Ψάλτης', 'Ψυλλάκης', 'Ψυχιάς',
    )

    last_names_female = (
        'Αβραμίδου', 'Αβραμπέκη', 'Αγγελάκη', 'Αγγελίδου', 'Αγγελουσοπούλου',
        'Αγραφιώτη', 'Αδαμοπούλου', 'Αθανασιάδη', 'Αθανασιάδου', 'Αλεξανδράκη',
        'Αλεξανδρίδου', 'Αλεξοπούλου', 'Αλυσανδράτου', 'Ανανιάδου', 'Αναστασάκη',
        'Αναστασίου', 'Ανεζάκη', 'Αντωνάκη', 'Αντωνίου', 'Αποστολάκη',
        'Αποστολίδου', 'Αραπάκη', 'Αραπίδου', 'Αργυράκη', 'Αργυρίου',
        'Αργυροπούλου', 'Αρματά', 'Αρσενάκη', 'Αρχάκη', 'Ασλανίδου', 'Ασουχίδου',
        'Ασσαργιωτάκη', 'Ατσαλάκη', 'Βαΐου', 'Βαβάση', 'Βαγενά', 'Βαζούρα',
        'Βαϊραμίδου', 'Βακουφτσή', 'Βαλεντή', 'Βαλιάκα', 'Βαλκάνου', 'Βαλσαμίδου',
        'Βαμβουκάκη', 'Βαρελίδου', 'Βαρθαλίτη', 'Βαρουτίδου', 'Βαρσάμου',
        'Βασιλάκη', 'Βασιλείου', 'Βασιλειάδη', 'Βασιλοπούλου', 'Βαφειάδου',
        'Βερβερίδου', 'Βερβίτη', 'Βλάσση', 'Βλαχοδήμου', 'Βλάχου', 'Βοσινάκη',
        'Βουλγαρίδου', 'Βουλτσίδου', 'Βουτσινά', 'Βραδή', 'Βρακά', 'Βράσκου',
        'Βυζιηνού', 'Γαβριήλ', 'Γαβριηλίδη', 'Γαλανάκη', 'Γαλάνη', 'Γαλανοπούλου',
        'Γεροκώστα', 'Γερούκη', 'Γεωργακοπούλου', 'Γεωργαρά', 'Γεωργή',
        'Γεωργιάδου', 'Γεωργίτση', 'Γεωργουλάκη', 'Γεωργούλα', 'Γιακαμόζη',
        'Γιαννακουδάκη', 'Γιανναρά', 'Γιαννοπούλου', 'Γιατράκου', 'Γκάβρου',
        'Γκάγκα', 'Γκαλίου', 'Γκιριτζιώνη', 'Γκόβα', 'Γκόνη', 'Γκούβα', 'Γκούνη',
        'Γούλα', 'Γούπα', 'Γραμμένου', 'Γρηγορίου', 'Γρηγοριάδου', 'Γρηγοροπούλου',
        'Γρίβα', 'Δαγλή', 'Δαΐκου', 'Δαμαλά', 'Δαματοπούλου', 'Δαμήλου',
        'Δανδανίδου', 'Δαρδιώτη', 'Δαρσακλή', 'Δαυίδ', 'Δάφνη', 'Δεδούκου', 'Δελή',
        'Δερλώπα', 'Δημακογιάννη', 'Δημητρίου', 'Δημητρέλου', 'Δημητριάδου',
        'Δημοπούλου', 'Δήμου', 'Δημτσούδη', 'Διακουμή', 'Διαμαντοπούλου',
        'Διοπούλου', 'Δούβαλη', 'Δουκίδου', 'Δουλάμη', 'Δουλγεράκη', 'Δουλουφάκη',
        'Δρακάκη', 'Δρακουλή', 'Δραμουντάνη', 'Δρίβα', 'Δρόσου', 'Δρυμαλίτου',
        'Δώρη', 'Ελευθερίου', 'Εμμανουήλ', 'Εμμανουηλίδου', 'Ενωτιάδη',
        'Ευαγγελάκη', 'Ευαγγελίδη', 'Ζαβιτσάνου', 'Ζαννίκου', 'Ζαρειφοπούλου',
        'Ζαρζάνη', 'Ζαφείρη', 'Ζαχαρίου', 'Ζαχαριουδάκη', 'Ζεγλίνα', 'Ζερβά',
        'Ζιάρα', 'Ζυγούρη', 'Ζώη', 'Ζωντανού', 'Θασίτου', 'Θεοδοσίου',
        'Θεοδοσιάδου', 'Θεοδωροπούλου', 'Θωμάκου', 'Ιωακείμ', 'Ιωακειμίδου',
        'Ιωσηφίδου', 'Καζαντζή', 'Κάκκα', 'Κακοτρίχη', 'Καλαθά', 'Καλαϊτζοπούλου',
        'Καλαμάρα', 'Καλδή', 'Καλέμη', 'Καλλιάνταση', 'Καλογιαννάκη', 'Καλογιάννη',
        'Καλομοίρη', 'Καλούδη', 'Καμινάρη', 'Καμπούρη', 'Κανελή', 'Κανελλή',
        'Κανελλοπούλου', 'Κανταρελή', 'Καπανταϊδάκη', 'Καπνιά', 'Καπουρνιώτη',
        'Καραγιάννη', 'Καραγιοβάννη', 'Καραγρηγορίου', 'Καραθανάση', 'Καρακυρίου',
        'Καρακωνσταντινού', 'Καρακώστα', 'Καραμάνη', 'Καραμανλή', 'Καράμπη',
        'Καραμπίνα', 'Καρανάνου', 'Καρανασίου', 'Καραντάνα', 'Καραογλάνη',
        'Καρατάσου', 'Καρβέλη', 'Καργάκου', 'Καρκαλέτση', 'Καρκανάκη', 'Καρολίδου',
        'Καρυδά', 'Κασκαούτη', 'Κασμιρλή', 'Κασσωτάκη', 'Κατσανίκου', 'Κατσαντώνη',
        'Κατσαφάδου', 'Κατσιγιάννη', 'Κατσιλλή', 'Κατσιμάλη', 'Κατσιμάνη',
        'Κατσούλα', 'Καφαντάρη', 'Καφφέ', 'Καχριμανίδη', 'Καψή', 'Κεσίση',
        'Κεσκίνη', 'Κετεσίδου', 'Κεφαλή', 'Κιορίδου', 'Κίτσου', 'Κλεινάκη',
        'Κοκκινίδου', 'Κοκκίνου', 'Κολαΐτου', 'Κόλλια', 'Κολτσάκη', 'Κονιάρη',
        'Κονσούλα', 'Κοντογεωργάκη', 'Κοντογιάννη', 'Κοντού', 'Κορομπόκη',
        'Κορωνίδου', 'Κοτρώτσου', 'Κοτσινά', 'Κουζουλά', 'Κουθούρη', 'Κουκουβά',
        'Κουκουθάκη', 'Κουλαουσάρη', 'Κουλουμπού', 'Κουλοχέρη', 'Κουμάρα',
        'Κουρλού', 'Κουτκιά', 'Κουτουζίδου', 'Κουτσικούρη', 'Κουτσιουμάρη',
        'Κουτσοβίδου', 'Κουτσονίκα', 'Κουτσούμπεη', 'Κουτσούμπη', 'Κουτσουνάκη',
        'Κουτσουρέλη', 'Κουφάκη', 'Κοφινάκη', 'Κυργιά', 'Κυριακοπούλου', 'Κυριάκου',
        'Κυριακούλη', 'Κυριαννάκη', 'Κυρίτση', 'Κυρκούδη', 'Κυρούδη',
        'Κωνσταντινίδου', 'Κωνσταντοπούλου', 'Κωστοπούλου', 'Κωτούλα',
        'Κωτσιονοπούλου', 'Κώτσου', 'Λαλαούνη', 'Λέκκα', 'Λεντζίου', 'Λεπίδα',
        'Λιάκου', 'Λιάνου', 'Λιναρδάκη', 'Λιολιοπούλου', 'Λιόντη', 'Λιούκα',
        'Λίτσιου', 'Λογκάκη', 'Λογοθέτη', 'Λουμπούτσκου', 'Λυμαξή', 'Λυρή', 'Λύτρα',
        'Μαγκανάρη', 'Μαγκαφοπούλου', 'Μαγούλα', 'Μακρή', 'Μακροπούλου', 'Μάλαμα',
        'Μαλίμη', 'Μαλλή', 'Μαμαλά', 'Μανέτα', 'Μανιάτη', 'Μανιτάρου', 'Μανοπούλου',
        'Μανουσοπούλου', 'Μαντά', 'Μάντου', 'Μαράκη', 'Μάρα', 'Μαργαριτάκη',
        'Μαργαρίτη', 'Μαργιά', 'Μαρκαντωνάκη', 'Μαρουγιάννη', 'Μαρτζούκου',
        'Μαρτιάδου', 'Μασαούτη', 'Μασιάλα', 'Μασίκα', 'Μαστραγγελή',
        'Μαστρογιαννίδου', 'Ματεντσίδου', 'Ματσούρη', 'Μαυρίδου', 'Μαυραειδή',
        'Μαυρίδη', 'Μαυροείδη', 'Μαυροπούλου', 'Μέλανι', 'Μενγκ', 'Μεξή',
        'Μηλιάδου', 'Μηλιάκη', 'Μηνά', 'Μητροπούλου', 'Μητσοπούλου', 'Μήτσου',
        'Μιλέα', 'Μισίδου', 'Μιχαηλίδου', 'Μιχαλάρου', 'Μιχελή', 'Μιχελακάκη',
        'Μίχου', 'Μοσχοβάκη', 'Μουτζούρη', 'Μπακοστεργίου', 'Μπακουλή', 'Μπαλή',
        'Μπαλαμπάνη', 'Μπαλανίκα', 'Μπαλάση', 'Μπαλλή', 'Μπαλτατζή', 'Μπαρκούτα',
        'Μπατζάνη', 'Μπατσάκη', 'Μπαφέρα', 'Μπαφίτη', 'Μπεκάκου', 'Μπελέκου',
        'Μπενέτου', 'Μπεσύρη', 'Μπίκα', 'Μπιμπίκα', 'Μπιμπίρη', 'Μπλιατσίου',
        'Μποζίκη', 'Μπονέλη', 'Μπότζα', 'Μποτζιώρη', 'Μπούζα', 'Μπραέσα',
        'Μπρούζου', 'Μπύρου', 'Μυλωνίδου', 'Μυτάρη', 'Μωραΐτη', 'Μωυσίδου',
        'Νάντσου', 'Ναούμ', 'Νάσσου', 'Νατσουλή', 'Νίκα', 'Νικολάτου', 'Νικολάου',
        'Νικολοπούλου', 'Νικολουδάκη', 'Νταγκαλή', 'Ντάνου', 'Ντανώλα', 'Ντζιαβίδα',
        'Ντόβα', 'Ντότση', 'Ντριβαλά', 'Νώε', 'Ξανθοπούλου', 'Ξενάκη', 'Ξενίδη',
        'Ξένου', 'Ξηρίδου', 'Ξηροδήμα', 'Ξηροτύρη', 'Ξυγκάκου', 'Οικονομοπούλου',
        'Οικονόμου', 'Ορφανίδου', 'Παλαιολογοπούλου', 'Παλαμπουγιούκη', 'Παλιεράκη',
        'Παλιούρα', 'Παναγιωτακοπούλου', 'Παναγιώτου', 'Πανκίδου', 'Πανοπούλου',
        'Πάνου', 'Πανταζή', 'Πάντζιου', 'Παντίσκα', 'Πάντου', 'Παπαγεωργίου',
        'Παπαδήμα', 'Παπαδημητροπούλου', 'Παπαδοπούλου', 'Παπαευαγγελίου',
        'Παπαευαγγέλου', 'Παπαθανασίου', 'Παπαθεοδοσίου', 'Παπαθωμά',
        'Παπακωνσταντίνου', 'Παπακώστα', 'Παπανάνου', 'Παπανδρέου',
        'Παπανδρικοπούλου', 'Παπανικολάου', 'Παπανώτα', 'Παπασπηλιωτοπούλου',
        'Παπασταύρου', 'Παπαστεργίου', 'Παπατζήκα', 'Παπαχρήστου', 'Παπουτσοπούλου',
        'Παππά', 'Παράνου', 'Παρασκευά', 'Πατελλή', 'Πατινιωτάκη', 'Πατσουρέα',
        'Παυλάκη', 'Παυλή', 'Παυλίδου', 'Πεμούση', 'Περουλάκη', 'Πετράκη',
        'Πετρίδου', 'Πετροσιάν', 'Πέτρου', 'Πέτση', 'Πετσιά', 'Πέττα', 'Πιπερίδη',
        'Πισκοπάνη', 'Πίσπα', 'Πλατάκη', 'Πολατίδου', 'Πολέμη', 'Πολίτου',
        'Πορφυριάδου', 'Ποσάντζη', 'Ποταμιάνου', 'Πουλή', 'Πουλιάση', 'Πουλίδα',
        'Πουρνάρα', 'Πρέκα', 'Προύβα', 'Πυροβόλου', 'Ραδιοπούλου', 'Ραυτοπούλου',
        'Ρέππα', 'Ρόγγα', 'Ροδίτου', 'Ρόκκα', 'Ρούσσου', 'Ρωμαίου', 'Σαββάκη',
        'Σακελλαρίου', 'Σακκή', 'Σαλέμη', 'Σαμπάνη', 'Σαμτανίδου', 'Σάουερ',
        'Σαπρίκη', 'Σαριδάκη', 'Σαρρή', 'Σγουρένα', 'Σδούκου', 'Σεβαστού',
        'Σελινοπούλου', 'Σεμπέπου', 'Σηκωτίδου', 'Σίββα', 'Σιδηροπούλου',
        'Σιμητοπούλου', 'Σιμιτζή', 'Σιόλου', 'Σιούτα', 'Σκαβέντζου', 'Σκασίλα',
        'Σκαφτούρου', 'Σκοτάδη', 'Σκούμπρου', 'Σκρεμμύδα', 'Σκυλογιάννη', 'Σμιτ',
        'Σοκολάκη', 'Σολωμίδου', 'Σόφρα', 'Σπαθάρη', 'Σπανίδου',
        'Σπανοχριστοδούλου', 'Σπασέγκου', 'Σπηλιάδου', 'Σπυριδάκη', 'Σταθά',
        'Σταματούκου', 'Σταμέλου', 'Σταμούλη', 'Σταυρίδου', 'Σταύρου', 'Στεφάνου',
        'Στούμπου', 'Στρατογιάννη', 'Στρούμπα', 'Στυλιανίδου', 'Συβιλιά',
        'Συμεωνίδου', 'Συνοδινού', 'Συρμού', 'Σύψα', 'Σφακιανάκη', 'Σωτηροπούλου',
        'Ταμπορρίνο', 'Τάντου', 'Ταξίδου', 'Τάσση', 'Τάτση', 'Ταυλαρίδου',
        'Ταφραλή', 'Τζάγκα', 'Τζαναβάρα', 'Τζιγκούρα', 'Τζιόβα', 'Τζιρατούδη',
        'Τζιωρτζή', 'Τόγια', 'Τόλη', 'Τομπουλίδου', 'Τόμπρη', 'Τοπαλή', 'Τοσούνη',
        'Τουλάκη', 'Τουλούπη', 'Τουρνά', 'Τραγούστη', 'Τρεντσίου', 'Τριανταφύλλου',
        'Τρίκα', 'Τριφτανίδου', 'Τρομπούκη', 'Τσάκη', 'Τσακαλάκου', 'Τσακίρη',
        'Τσαμοπούλου', 'Τσαμπαλή', 'Τσαμπούρη', 'Τσαμτσούρη', 'Τσανάκα',
        'Τσαντίδου', 'Τσάτη', 'Τσαχάκη', 'Τσέτου', 'Τσετσέρη', 'Τσικνή', 'Τσικρίκα',
        'Τσίμη', 'Τσιομπάνη', 'Τσιούπρα', 'Τσιπλίκωφ', 'Τσιωλξ', 'Τσουκιά',
        'Τσουνάκου', 'Τσουράκη', 'Τσούρα', 'Τσώνη', 'Τυμβίου', 'Υφαντή', 'Φαββάτα',
        'Φαρμάκη', 'Φασατάκη', 'Φασουλή', 'Φασουλίδου', 'Φειζατίδου', 'Φιδάνη',
        'Φιλιάγκου', 'Φιλίππου', 'Φίλκα', 'Φλασκή', 'Φουρκιώτη', 'Φραγκιαδάκη',
        'Φραγκουδάκη', 'Φρονιμάκη', 'Φυτιλή', 'Φωλιά', 'Φωτακοπούλου', 'Φωτιάδου',
        'Χαλαντζούκα', 'Χαλβατζή', 'Χαλκίδου', 'Χαμαλίδου', 'Χανταμπή', 'Χαντζή',
        'Χαραλαμπίδου', 'Χασάπη', 'Χατζή', 'Χατζηβλασίου', 'Χατζηγεωργίου',
        'Χατζηδάκη', 'Χατζημιχαήλ', 'Χατζηφώτη', 'Χατζηχαρίστου', 'Χιωτίδου',
        'Χολέβα', 'Χονδρούδη', 'Χοντζιά', 'Χορόζη', 'Χορτάτου', 'Χουρζαμάνη',
        'Χρήστου', 'Χριστογιάννη', 'Χριστοδούλου', 'Χριστοπούλου', 'Χριστοφόρη',
        'Χρονοπούλου', 'Χρυσανθακοπούλου', 'Χρυσάφη', 'Χρυσικάκη', 'Χωριανοπούλου',
        'Χωρινού', 'Ψυρρή', 'Ψυχάρη',
    )

    last_names = last_names_male + last_names_female
